# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DINFO_METADATA = Metadata(
    id="c0b7ae1e6ddb0557936952320119fb7853d0bfcd.boutiques",
    name="3dinfo",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dinfoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dinfo(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    info: list[str]
    """Sort-of-useful information from a 3D dataset's header"""


def v_3dinfo(
    dataset: list[InputPathType],
    orient: bool = False,
    lextent: bool = False,
    rextent: bool = False,
    aextent: bool = False,
    pextent: bool = False,
    iextent: bool = False,
    sextent: bool = False,
    all_names: bool = False,
    verb: bool = False,
    very_verbose: bool = False,
    short: bool = False,
    no_hist: bool = False,
    h: bool = False,
    help_: bool = False,
    extreme_help: bool = False,
    h_view: bool = False,
    h_web: bool = False,
    h_find: str | None = None,
    h_raw: bool = False,
    h_spx: bool = False,
    h_aspx: bool = False,
    all_opts: bool = False,
    label2index: str | None = None,
    niml_hdr: bool = False,
    subbrick_info: bool = False,
    exists: bool = False,
    id_: bool = False,
    is_atlas: bool = False,
    is_atlas_or_labeltable: bool = False,
    is_nifti: bool = False,
    dset_extension: bool = False,
    storage_mode: bool = False,
    space: bool = False,
    gen_space: bool = False,
    av_space: bool = False,
    nifti_code: bool = False,
    is_oblique: bool = False,
    handedness: bool = False,
    obliquity: bool = False,
    prefix: bool = False,
    prefix_noext: bool = False,
    ni: bool = False,
    nj: bool = False,
    nk: bool = False,
    nijk: bool = False,
    nv: bool = False,
    nt_: bool = False,
    n4: bool = False,
    nvi: bool = False,
    nti: bool = False,
    ntimes: bool = False,
    max_node: bool = False,
    di: bool = False,
    dj: bool = False,
    dk: bool = False,
    d3: bool = False,
    adi: bool = False,
    adj: bool = False,
    adk: bool = False,
    ad3: bool = False,
    voxvol: bool = False,
    oi: bool = False,
    oj: bool = False,
    ok: bool = False,
    o3: bool = False,
    dcx: bool = False,
    dcy: bool = False,
    dcz: bool = False,
    dc3: bool = False,
    tr: bool = False,
    dmin: bool = False,
    dmax: bool = False,
    dminus: bool = False,
    dmaxus: bool = False,
    smode: bool = False,
    header_name: bool = False,
    brick_name: bool = False,
    iname: bool = False,
    extent: bool = False,
    fac: bool = False,
    label: bool = False,
    datum: bool = False,
    min_: bool = False,
    max_: bool = False,
    minus: bool = False,
    maxus: bool = False,
    labeltable: bool = False,
    labeltable_as_atlas_points: bool = False,
    atlas_points: bool = False,
    history: bool = False,
    slice_timing: bool = False,
    header_line: bool = False,
    hdr: bool = False,
    sb_delim: str | None = None,
    na_flag: str | None = None,
    atr_delim: str | None = None,
    aform_real: bool = False,
    aform_real_oneline: bool = False,
    aform_real_refit_ori: bool = False,
    is_aform_real_orth: bool = False,
    aform_orth: bool = False,
    perm_to_orient: str | None = None,
    same_grid: bool = False,
    same_dim: bool = False,
    same_delta: bool = False,
    same_orient: bool = False,
    same_center: bool = False,
    same_obl: bool = False,
    same_all_grid: bool = False,
    val_diff: bool = False,
    sval_diff: bool = False,
    monog_pairs: bool = False,
    runner: Runner | None = None,
) -> V3dinfoOutputs:
    """
    Prints out sort-of-useful information from a 3D dataset's header.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        dataset: Datasets to retrieve information from.
        orient: Value of orientation string. For example, LPI means: i\
            direction grows from Left(negative) to Right(positive). j direction\
            grows from Posterior (neg.) to Anterior (pos.) k direction grows from\
            Inferior (neg.) to Superior (pos.).
        lextent: Extent along L.
        rextent: Extent along R.
        aextent: Extent along A.
        pextent: Extent along P.
        iextent: Extent along I.
        sextent: Extent along S.
        all_names: Value of various dset structures handling filenames.
        verb: Print out lots of information.
        very_verbose: Print out even more information including slice time\
            offsets.
        short: Print out less information (default).
        no_hist: Omit the HISTORY text.
        h: Mini help.
        help_: Display entire help output.
        extreme_help: Extreme help.
        h_view: Open help in text editor.
        h_web: Open help in web browser.
        h_find: Look for lines in help output that match WORD.
        h_raw: Display unedited help string.
        h_spx: Help string in sphinx format without autoformatting options.
        h_aspx: Help string in sphinx format with autoformatting options.
        all_opts: Try to identify all options for the program from the help\
            output.
        label2index: Output index corresponding to label.
        niml_hdr: Output entire NIML-formatted header.
        subbrick_info: Output only sub-brick part of information.
        exists: 1 if dset is loadable, 0 otherwise. This works on prefix also.
        id_: Idcodestring of dset.
        is_atlas: 1 if dset is an atlas.
        is_atlas_or_labeltable: 1 if dset has an atlas or labeltable.
        is_nifti: 1 if dset is NIFTI format, 0 otherwise.
        dset_extension: Show filename extension for valid dataset (e.g.\
            .nii.gz).
        storage_mode: Show internal storage mode of dataset (e.g. NIFTI).
        space: Dataset's space.
        gen_space: Dataset's generic space.
        av_space: AFNI format's view extension for the space.
        nifti_code: What AFNI would use for an output NIFTI (q)sform_code.
        is_oblique: 1 if dset is oblique.
        handedness: L if orientation is Left handed, R if it is right handed.
        obliquity: Angle from plumb direction. Angles of 0 (or close) are for\
            cardinal orientations.
        prefix: Return the prefix.
        prefix_noext: Return the prefix without extensions.
        ni: Return the number of voxels in i dimension.
        nj: Return the number of voxels in j dimension.
        nk: Return the number of voxels in k dimension.
        nijk: Return ni*nj*nk.
        nv: Return number of points in time or the number of sub-bricks.
        nt_: Same as -nv.
        n4: Same as -ni -nj -nk -nv.
        nvi: The maximum sub-brick index (= nv -1 ).
        nti: Same as -nvi.
        ntimes: Return number of sub-bricks points in time. This is an option\
            for debugging use, stay away from it.
        max_node: For a surface-based dset, return the maximum node index.
        di: Signed displacement per voxel along i direction, aka dx.
        dj: Signed displacement per voxel along j direction, aka dy.
        dk: Signed displacement per voxel along k direction, aka dz.
        d3: Same as -di -dj -dk.
        adi: Voxel size along i direction (abs(di)).
        adj: Voxel size along j direction (abs(dj)).
        adk: Voxel size along k direction (abs(dk)).
        ad3: Same as -adi -adj -adk.
        voxvol: Voxel volume in cubic millimeters.
        oi: Volume origin along the i direction.
        oj: Volume origin along the j direction.
        ok: Volume origin along the k direction.
        o3: Same as -oi -oj -ok.
        dcx: Volumetric center in x direction (DICOM coordinates).
        dcy: Volumetric center in y direction (DICOM coordinates).
        dcz: Volumetric center in z direction (DICOM coordinates).
        dc3: Same as -dcx -dcy -dcz.
        tr: The TR value in seconds.
        dmin: The dataset's minimum value, scaled by fac.
        dmax: The dataset's maximum value, scaled by fac.
        dminus: The dataset's minimum value, unscaled.
        dmaxus: The dataset's maximum value, unscaled.
        smode: Dset storage mode string.
        header_name: Value of dset structure (sub)field 'header_name'.
        brick_name: Value of dset structure (sub)field 'brick_name'.
        iname: Name of dset as input on the command line.
        extent: The spatial extent of the dataset along R, L, A, P, I and S.
        fac: Return the float scaling factor.
        label: The label of each sub-brick.
        datum: The data storage type.
        min_: The minimum value, scaled by fac.
        max_: The maximum value, scaled by fac.
        minus: The minimum value, unscaled.
        maxus: The maximum value, unscaled.
        labeltable: Show label table, if any.
        labeltable_as_atlas_points: Show label table in atlas point format.
        atlas_points: Show atlas points list, if any.
        history: History note.
        slice_timing: Show slice timing.
        header_line: Output as the first line the names of attributes in each\
            field (column).
        hdr: Same as -header_line.
        sb_delim: Delimiter string between sub-brick values. Default SB_DELIM\
            is '|'.
        na_flag: String to use when a field is not found or not applicable.\
            Default is 'NA'.
        atr_delim: Delimiter string between attributes. Default ATR_DELIM is\
            the tab character.
        aform_real: Display full 3x4 'aform_real' matrix (AFNI's RAI equivalent\
            of the sform matrix in NIFTI, may contain obliquity info), with comment\
            line first.
        aform_real_oneline: Display full 'aform_real' matrix (see\
            '-aform_real') as 1 row of 12 numbers. No additional comment.
        aform_real_refit_ori: Display full 3x4 'aform_real' matrix (see\
            '-aform_real') *if* the dset were reoriented (via 3drefit) to new\
            orient XXX. Includes comment line first.
        is_aform_real_orth: If true, aform_real == aform_orth, which should be\
            a very common occurrence.
        aform_orth: Display full 3x4 'aform_orth' matrix (AFNI's RAI matrix\
            equivalent of the NIFTI quaternion, which may contain obliquity info),\
            with comment line first. This matrix is the orthogonalized form of\
            aform_real, and very often AFNI-produced dsets, we will have:\
            aform_orth == aform_real.
        perm_to_orient: Display 3x3 permutation matrix to go from the dset's\
            current orientation to the YYY orient.
        same_grid: Output 1 if the grid is identical between two dsets, 0\
            otherwise. For -same_grid to be 1, all of -same_dim, -same_delta,\
            -same_orient, -same_center, and -same_obl must return 1.
        same_dim: 1 if dimensions (nx, ny, nz) are the same between dset pairs.
        same_delta: 1 if voxel sizes are the same between dset pairs.
        same_orient: 1 if orientation is the same between dset pairs.
        same_center: 1 if geometric center is the same between dset pairs.
        same_obl: 1 if obliquity is the same between dset pairs.
        same_all_grid: Equivalent to listing all of -same_dim, -same_delta,\
            -same_orient, -same_center, and -same_obl on the command line.
        val_diff: Output the sum of absolute differences of all voxels in the\
            dataset pair. A -1.0 value indicates a grid mismatch between volume\
            pairs.
        sval_diff: Same as -val_diff, but the sum is divided (scaled) by the\
            total number of voxels that are not zero in at least one of the two\
            datasets.
        monog_pairs: Instead of pairing each dset with the first, pair each\
            couple separately. This requires you to have an even number of dsets on\
            the command line.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dinfoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DINFO_METADATA)
    cargs = []
    cargs.append("3dinfo")
    if orient:
        cargs.append("-orient")
    if lextent:
        cargs.append("-Lextent")
    if rextent:
        cargs.append("-Rextent")
    if aextent:
        cargs.append("-Aextent")
    if pextent:
        cargs.append("-Pextent")
    if iextent:
        cargs.append("-Iextent")
    if sextent:
        cargs.append("-Sextent")
    if all_names:
        cargs.append("-all_names")
    if verb:
        cargs.append("-verb")
    if very_verbose:
        cargs.append("-VERB")
    if short:
        cargs.append("-short")
    if no_hist:
        cargs.append("-no_hist")
    if h:
        cargs.append("-h")
    if help_:
        cargs.append("-help")
    if extreme_help:
        cargs.append("-HELP")
    if h_view:
        cargs.append("-h_view")
    if h_web:
        cargs.append("-h_web")
    if h_find is not None:
        cargs.extend([
            "-h_find",
            h_find
        ])
    if h_raw:
        cargs.append("-h_raw")
    if h_spx:
        cargs.append("-h_spx")
    if h_aspx:
        cargs.append("-h_aspx")
    if all_opts:
        cargs.append("-all_opts")
    if label2index is not None:
        cargs.extend([
            "-label2index",
            label2index
        ])
    if niml_hdr:
        cargs.append("-niml_hdr")
    if subbrick_info:
        cargs.append("-subbrick_info")
    if exists:
        cargs.append("-exists")
    if id_:
        cargs.append("-id")
    if is_atlas:
        cargs.append("-is_atlas")
    if is_atlas_or_labeltable:
        cargs.append("-is_atlas_or_labeltable")
    if is_nifti:
        cargs.append("-is_nifti")
    if dset_extension:
        cargs.append("-dset_extension")
    if storage_mode:
        cargs.append("-storage_mode")
    if space:
        cargs.append("-space")
    if gen_space:
        cargs.append("-gen_space")
    if av_space:
        cargs.append("-av_space")
    if nifti_code:
        cargs.append("-nifti_code")
    if is_oblique:
        cargs.append("-is_oblique")
    if handedness:
        cargs.append("-handedness")
    if obliquity:
        cargs.append("-obliquity")
    if prefix:
        cargs.append("-prefix")
    if prefix_noext:
        cargs.append("-prefix_noext")
    if ni:
        cargs.append("-ni")
    if nj:
        cargs.append("-nj")
    if nk:
        cargs.append("-nk")
    if nijk:
        cargs.append("-nijk")
    if nv:
        cargs.append("-nv")
    if nt_:
        cargs.append("-nt")
    if n4:
        cargs.append("-n4")
    if nvi:
        cargs.append("-nvi")
    if nti:
        cargs.append("-nti")
    if ntimes:
        cargs.append("-ntimes")
    if max_node:
        cargs.append("-max_node")
    if di:
        cargs.append("-di")
    if dj:
        cargs.append("-dj")
    if dk:
        cargs.append("-dk")
    if d3:
        cargs.append("-d3")
    if adi:
        cargs.append("-adi")
    if adj:
        cargs.append("-adj")
    if adk:
        cargs.append("-adk")
    if ad3:
        cargs.append("-ad3")
    if voxvol:
        cargs.append("-voxvol")
    if oi:
        cargs.append("-oi")
    if oj:
        cargs.append("-oj")
    if ok:
        cargs.append("-ok")
    if o3:
        cargs.append("-o3")
    if dcx:
        cargs.append("-dcx")
    if dcy:
        cargs.append("-dcy")
    if dcz:
        cargs.append("-dcz")
    if dc3:
        cargs.append("-dc3")
    if tr:
        cargs.append("-tr")
    if dmin:
        cargs.append("-dmin")
    if dmax:
        cargs.append("-dmax")
    if dminus:
        cargs.append("-dminus")
    if dmaxus:
        cargs.append("-dmaxus")
    if smode:
        cargs.append("-smode")
    if header_name:
        cargs.append("-header_name")
    if brick_name:
        cargs.append("-brick_name")
    if iname:
        cargs.append("-iname")
    if extent:
        cargs.append("-extent")
    if fac:
        cargs.append("-fac")
    if label:
        cargs.append("-label")
    if datum:
        cargs.append("-datum")
    if min_:
        cargs.append("-min")
    if max_:
        cargs.append("-max")
    if minus:
        cargs.append("-minus")
    if maxus:
        cargs.append("-maxus")
    if labeltable:
        cargs.append("-labeltable")
    if labeltable_as_atlas_points:
        cargs.append("-labeltable_as_atlas_points")
    if atlas_points:
        cargs.append("-atlas_points")
    if history:
        cargs.append("-history")
    if slice_timing:
        cargs.append("-slice_timing")
    if header_line:
        cargs.append("-header_line")
    if hdr:
        cargs.append("-hdr")
    if sb_delim is not None:
        cargs.extend([
            "-sb_delim",
            sb_delim
        ])
    if na_flag is not None:
        cargs.extend([
            "-NA_flag",
            na_flag
        ])
    if atr_delim is not None:
        cargs.extend([
            "-atr_delim",
            atr_delim
        ])
    if aform_real:
        cargs.append("-aform_real")
    if aform_real_oneline:
        cargs.append("-aform_real_oneline")
    if aform_real_refit_ori:
        cargs.append("-aform_real_refit_ori")
    if is_aform_real_orth:
        cargs.append("-is_aform_real_orth")
    if aform_orth:
        cargs.append("-aform_orth")
    if perm_to_orient is not None:
        cargs.extend([
            "-perm_to_orient",
            perm_to_orient
        ])
    if same_grid:
        cargs.append("-same_grid")
    if same_dim:
        cargs.append("-same_dim")
    if same_delta:
        cargs.append("-same_delta")
    if same_orient:
        cargs.append("-same_orient")
    if same_center:
        cargs.append("-same_center")
    if same_obl:
        cargs.append("-same_obl")
    if same_all_grid:
        cargs.append("-same_all_grid")
    if val_diff:
        cargs.append("-val_diff")
    if sval_diff:
        cargs.append("-sval_diff")
    if monog_pairs:
        cargs.append("-monog_pairs")
    cargs.extend([execution.input_file(f) for f in dataset])
    ret = V3dinfoOutputs(
        root=execution.output_file("."),
        info=[],
    )
    execution.run(cargs, handle_stdout=lambda s: ret.info.append(s))
    return ret


__all__ = [
    "V3dinfoOutputs",
    "V_3DINFO_METADATA",
    "v_3dinfo",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FS_SPMREG_GLNXA64_METADATA = Metadata(
    id="d96fd1d83e2b7bf77ac2922d1bead84c42091878.boutiques",
    name="fs_spmreg.glnxa64",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FsSpmregGlnxa64Outputs(typing.NamedTuple):
    """
    Output object returned when calling `fs_spmreg_glnxa64(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_matrix_file: OutputPathType
    """Output registration matrix file"""


def fs_spmreg_glnxa64(
    runner: Runner | None = None,
) -> FsSpmregGlnxa64Outputs:
    """
    fs_spmreg is a tool for registration using SPM within FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FsSpmregGlnxa64Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FS_SPMREG_GLNXA64_METADATA)
    cargs = []
    cargs.append("fs_spmreg")
    cargs.append("[OPTIONS]")
    ret = FsSpmregGlnxa64Outputs(
        root=execution.output_file("."),
        output_matrix_file=execution.output_file("[OUTPUT_MATRIX]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FS_SPMREG_GLNXA64_METADATA",
    "FsSpmregGlnxa64Outputs",
    "fs_spmreg_glnxa64",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__IS_OBLIQUE_METADATA = Metadata(
    id="2e3c80c4806683277ce568a5d838cb3d495df099.boutiques",
    name="@isOblique",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VIsObliqueOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__is_oblique(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    result: OutputPathType
    """Output result indicating if the file is oblique or plumb"""


def v__is_oblique(
    infile: InputPathType,
    runner: Runner | None = None,
) -> VIsObliqueOutputs:
    """
    Determine if a file is oblique or plumb.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        infile: Input file (e.g., Hello+orig.HEAD).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VIsObliqueOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__IS_OBLIQUE_METADATA)
    cargs = []
    cargs.append("@isOblique")
    cargs.append(execution.input_file(infile))
    ret = VIsObliqueOutputs(
        root=execution.output_file("."),
        result=execution.output_file("oblique_check_result.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VIsObliqueOutputs",
    "V__IS_OBLIQUE_METADATA",
    "v__is_oblique",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURF2_VOL_COORD_METADATA = Metadata(
    id="a33b1b240a4fa87f79ece3a7f2283645dc3cfa8c.boutiques",
    name="Surf2VolCoord",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class Surf2VolCoordOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surf2_vol_coord(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    results_file: OutputPathType
    """Output results file."""


def surf2_vol_coord(
    surface: str,
    grid_vol: InputPathType,
    closest_nodes: InputPathType,
    prefix: str,
    grid_subbrick: float | None = None,
    sv: InputPathType | None = None,
    one_node: str | None = None,
    qual: str | None = None,
    lpi: bool = False,
    rai: bool = False,
    verb_level: float | None = None,
    runner: Runner | None = None,
) -> Surf2VolCoordOutputs:
    """
    Relates node indices to coordinates given x y z coordinates and returns the
    nodes closest to them.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        surface: Specify input surface.
        grid_vol: Specifies the grid for the output volume.
        closest_nodes: A coordinate file specifying coordinates for which the\
            closest nodes will be found.
        prefix: Output results to file PREFIX (will overwrite). Default is\
            stdout.
        grid_subbrick: Sub-brick from which data are taken.
        sv: Surface Volume file aligning with the surface.
        one_node: Specify a single node's coordinates.
        qual: A string of characters that qualify the surface in which the\
            closest node was found.
        lpi: Coordinate axis direction for values in XYZ.1D are in LPI.
        rai: Coordinate axis direction for values in XYZ.1D are in RAI\
            (default).
        verb_level: Verbosity level, default is 0.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Surf2VolCoordOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURF2_VOL_COORD_METADATA)
    cargs = []
    cargs.append("Surf2VolCoord")
    cargs.extend([
        "-i_TYPE",
        surface
    ])
    cargs.extend([
        "-grid_parent",
        execution.input_file(grid_vol)
    ])
    if grid_subbrick is not None:
        cargs.extend([
            "-grid_subbrick",
            str(grid_subbrick)
        ])
    if sv is not None:
        cargs.extend([
            "-sv",
            execution.input_file(sv)
        ])
    if one_node is not None:
        cargs.extend([
            "-one_node",
            one_node
        ])
    cargs.extend([
        "-closest_nodes",
        execution.input_file(closest_nodes)
    ])
    if qual is not None:
        cargs.extend([
            "-qual",
            qual
        ])
    if lpi:
        cargs.append("-LPI")
    if rai:
        cargs.append("-RAI")
    if verb_level is not None:
        cargs.extend([
            "-verb",
            str(verb_level)
        ])
    cargs.extend([
        "-prefix",
        prefix
    ])
    ret = Surf2VolCoordOutputs(
        root=execution.output_file("."),
        results_file=execution.output_file(prefix),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURF2_VOL_COORD_METADATA",
    "Surf2VolCoordOutputs",
    "surf2_vol_coord",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

N4_BIAS_FIELD_CORRECTION_METADATA = Metadata(
    id="430c0cf662702b145c28eac54a52db1b1f1ee70a.boutiques",
    name="N4BiasFieldCorrection",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


@dataclasses.dataclass
class N4BiasFieldCorrectionConvergence:
    """
    -c, --convergence
    [<numberOfIterations=50x50x50x50>,<convergenceThreshold=0.0>]. Convergence
    is determined by calculating the coefficient of variation between subsequent
    iterations. When this value is less than the specified threshold from the
    previous iteration or the maximum number of iterations is exceeded the
    program terminates. Multiple resolutions can be specified by using 'x'
    between the number of iterations at each resolution, e.g. 100x50x50.
    """
    convergence: list[int]
    convergence_threshold: float | None = None
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        if self.convergence_threshold is not None:
            cargs.append("[" + "x".join(map(str, self.convergence)) + "," + str(self.convergence_threshold) + "]")
        return cargs


@dataclasses.dataclass
class N4BiasFieldCorrectionBsplineFitting:
    """
    -b, --bspline-fitting [splineDistance,<splineOrder=3>]. These options
    describe the b-spline fitting parameters. The initial b-spline mesh at the
    coarsest resolution is specified either as the number of elements in each
    dimension, e.g. 2x2x3 for 3-D images, or it can be specified as a single
    scalar parameter which describes the isotropic sizing of the mesh elements.
    The latter option is typically preferred. For each subsequent level, the
    spline distance decreases in half, or equivalently, the number of mesh
    elements doubles Cubic splines (order = 3) are typically used. The default
    setting is to employ a single mesh element over the entire domain, i.e., -b
    [1x1x1,3].
    """
    spline_distance: list[float]
    spline_order: int | None = None
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        if self.spline_order is not None:
            cargs.append("[" + "x".join(map(str, self.spline_distance)) + "," + str(self.spline_order) + "]")
        return cargs


@dataclasses.dataclass
class N4BiasFieldCorrectionHistogramSharpening:
    """
    -t, --histogram-sharpening
    [<FWHM=0.15>,<wienerNoise=0.01>,<numberOfHistogramBins=200>]. These options
    describe the histogram sharpening parameters, i.e. the deconvolution step
    parameters described in the original N3 algorithm. The default values have
    been shown to work fairly well.
    """
    fwhm: float | None = None
    wiener_noise: float | None = None
    number_of_histogram_bins: int | None = None
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        if self.fwhm is not None or self.wiener_noise is not None or self.number_of_histogram_bins is not None:
            cargs.append("[" + (str(self.fwhm) if (self.fwhm is not None) else "") + "," + (str(self.wiener_noise) if (self.wiener_noise is not None) else "") + "," + (str(self.number_of_histogram_bins) if (self.number_of_histogram_bins is not None) else "") + "]")
        return cargs


class N4BiasFieldCorrectionOutputs(typing.NamedTuple):
    """
    Output object returned when calling `n4_bias_field_correction(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    corrected_image: OutputPathType
    """The bias corrected version of the input image."""
    bias_field: OutputPathType | None
    """Estimated bias field image."""


def n4_bias_field_correction(
    input_image: InputPathType,
    corrected_image_path: str,
    image_dimensionality: typing.Literal[2, 3, 4] | None = None,
    shrink_factor: int | None = None,
    mask_image: InputPathType | None = None,
    rescale_intensities: typing.Literal[0, 1] | None = None,
    weight_image: InputPathType | None = None,
    convergence: N4BiasFieldCorrectionConvergence | None = None,
    bspline_fitting: N4BiasFieldCorrectionBsplineFitting | None = None,
    histogram_sharpening: N4BiasFieldCorrectionHistogramSharpening | None = None,
    verbose: typing.Literal[0, 1] | None = None,
    bias_field_path: str | None = None,
    runner: Runner | None = None,
) -> N4BiasFieldCorrectionOutputs:
    """
    N4 is a variant of the popular N3 (nonparameteric nonuniform normalization)
    retrospective bias correction algorithm. Based on the assumption that the
    corruption of the low frequency bias field can be modeled as a convolution of
    the intensity histogram by a Gaussian, the basic algorithmic protocol is to
    iterate between deconvolving the intensity histogram by a Gaussian, remapping
    the intensities, and then spatially smoothing this result by a B-spline modeling
    of the bias field itself.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        input_image: -i, --input-image inputImageFilename. A scalar image is\
            expected as input for bias correction. Since N4 log transforms the\
            intensities, negative values or values close to zero should be\
            processed prior to correction.
        corrected_image_path: The bias corrected version of the input image.
        image_dimensionality: -d, --image-dimensionality 2/3/4. This option\
            forces the image to be treated as a specified-dimensional image. If not\
            specified, N4 tries to infer the dimensionality from the input image.
        shrink_factor: -s, --shrink-factor 1/2/3/(4)/... Running N4 on large\
            images can be time consuming. To lessen computation time, the input\
            image can be resampled. The shrink factor, specified as a single\
            integer, describes this resampling. Shrink factors <= 4 are commonly\
            used. Note that the shrink factor is only applied to the first two or\
            three dimensions which we assume are spatial.
        mask_image: -x, --mask-image maskImageFilename. If a mask image is\
            specified, the final bias correction is only performed in the mask\
            region. If a weight image is not specified, only intensity values\
            inside the masked region are used during the execution of the\
            algorithm. If a weight image is specified, only the non-zero weights\
            are used in the execution of the algorithm although the mask region\
            defines where bias correction is performed in the final output.\
            Otherwise bias correction occurs over the entire image domain. See also\
            the option description for the weight image. If a mask image is *not*\
            specified then the entire image region will be used as the mask region.\
            Note that this is different than the N3 implementation which uses the\
            results of Otsu thresholding to define a mask. However, this leads to\
            unknown anatomical regions being included and excluded during the bias\
            correction.
        rescale_intensities: -r, --rescale-intensities 0/(1). At each\
            iteration, a new intensity mapping is calculated and applied but there\
            is nothing which constrains the new intensity range to be within\
            certain values. The result is that the range can "drift" from the\
            original at each iteration. This option rescales to the [min,max] range\
            of the original image intensities within the user-specified mask. A\
            mask is required to perform rescaling.
        weight_image: -w, --weight-image weightImageFilename. The weight image\
            allows the user to perform a relative weighting of specific voxels\
            during the B-spline fitting. For example, some studies have shown that\
            N3 performed on white matter segmentations improves performance. If one\
            has a spatial probability map of the white matter, one can use this map\
            to weight the b-spline fitting towards those voxels which are more\
            probabilistically classified as white matter. See also the option\
            description for the mask image.
        convergence: -c, --convergence\
            [<numberOfIterations=50x50x50x50>,<convergenceThreshold=0.0>].\
            Convergence is determined by calculating the coefficient of variation\
            between subsequent iterations. When this value is less than the\
            specified threshold from the previous iteration or the maximum number\
            of iterations is exceeded the program terminates. Multiple resolutions\
            can be specified by using 'x' between the number of iterations at each\
            resolution, e.g. 100x50x50.
        bspline_fitting: -b, --bspline-fitting\
            [splineDistance,<splineOrder=3>]. These options describe the b-spline\
            fitting parameters. The initial b-spline mesh at the coarsest\
            resolution is specified either as the number of elements in each\
            dimension, e.g. 2x2x3 for 3-D images, or it can be specified as a\
            single scalar parameter which describes the isotropic sizing of the\
            mesh elements. The latter option is typically preferred. For each\
            subsequent level, the spline distance decreases in half, or\
            equivalently, the number of mesh elements doubles Cubic splines (order\
            = 3) are typically used. The default setting is to employ a single mesh\
            element over the entire domain, i.e., -b [1x1x1,3].
        histogram_sharpening: -t, --histogram-sharpening\
            [<FWHM=0.15>,<wienerNoise=0.01>,<numberOfHistogramBins=200>]. These\
            options describe the histogram sharpening parameters, i.e. the\
            deconvolution step parameters described in the original N3 algorithm.\
            The default values have been shown to work fairly well.
        verbose: Verbose output.
        bias_field_path: Estimated bias field image.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `N4BiasFieldCorrectionOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(N4_BIAS_FIELD_CORRECTION_METADATA)
    cargs = []
    cargs.append("N4BiasFieldCorrection")
    if image_dimensionality is not None:
        cargs.extend([
            "--image-dimensionality",
            str(image_dimensionality)
        ])
    if shrink_factor is not None:
        cargs.extend([
            "--shrink-factor",
            str(shrink_factor)
        ])
    if mask_image is not None:
        cargs.extend([
            "--mask-image",
            execution.input_file(mask_image)
        ])
    if rescale_intensities is not None:
        cargs.extend([
            "--rescale-intensities",
            str(rescale_intensities)
        ])
    if weight_image is not None:
        cargs.extend([
            "--weight-image",
            execution.input_file(weight_image)
        ])
    if convergence is not None:
        cargs.extend([
            "--convergence",
            *convergence.run(execution)
        ])
    if bspline_fitting is not None:
        cargs.extend([
            "--bspline-fitting",
            *bspline_fitting.run(execution)
        ])
    if histogram_sharpening is not None:
        cargs.extend([
            "--histogram-sharpening",
            *histogram_sharpening.run(execution)
        ])
    if verbose is not None:
        cargs.extend([
            "--verbose",
            str(verbose)
        ])
    cargs.extend([
        "--input-image",
        execution.input_file(input_image)
    ])
    cargs.append("--output")
    if bias_field_path is not None:
        cargs.append("[" + corrected_image_path + "," + bias_field_path + "]")
    ret = N4BiasFieldCorrectionOutputs(
        root=execution.output_file("."),
        corrected_image=execution.output_file(corrected_image_path),
        bias_field=execution.output_file(bias_field_path) if (bias_field_path is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "N4BiasFieldCorrectionBsplineFitting",
    "N4BiasFieldCorrectionConvergence",
    "N4BiasFieldCorrectionHistogramSharpening",
    "N4BiasFieldCorrectionOutputs",
    "N4_BIAS_FIELD_CORRECTION_METADATA",
    "n4_bias_field_correction",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_PROBEDICOM_METADATA = Metadata(
    id="e881c56e43ccca97c6f0346fbb32f30273bb1fbf.boutiques",
    name="mri_probedicom",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriProbedicomOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_probedicom(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Text file containing extracted information from DICOM."""


def mri_probedicom(
    dicom_file: InputPathType,
    option1: str | None = None,
    option2: str | None = None,
    runner: Runner | None = None,
) -> MriProbedicomOutputs:
    """
    Utility to probe DICOM files for information.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        dicom_file: DICOM file to be probed.
        option1: Description for option1.
        option2: Description for option2.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriProbedicomOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_PROBEDICOM_METADATA)
    cargs = []
    cargs.append("mri_probedicom")
    cargs.append(execution.input_file(dicom_file))
    if option1 is not None:
        cargs.extend([
            "-option1",
            option1
        ])
    if option2 is not None:
        cargs.extend([
            "-option2",
            option2
        ])
    ret = MriProbedicomOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file("[OUTPUT].txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_PROBEDICOM_METADATA",
    "MriProbedicomOutputs",
    "mri_probedicom",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

METRIC_EXTREMA_METADATA = Metadata(
    id="a2f46a01c07390207099bf087477bc693bc124ec.boutiques",
    name="metric-extrema",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class MetricExtremaPresmooth:
    """
    smooth the metric before finding extrema.
    """
    kernel: float
    """the size of the gaussian smoothing kernel in mm, as sigma by default"""
    opt_fwhm: bool = False
    """kernel size is FWHM, not sigma"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-presmooth")
        cargs.append(str(self.kernel))
        if self.opt_fwhm:
            cargs.append("-fwhm")
        return cargs


@dataclasses.dataclass
class MetricExtremaThreshold:
    """
    ignore small extrema.
    """
    low: float
    """the largest value to consider for being a minimum"""
    high: float
    """the smallest value to consider for being a maximum"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-threshold")
        cargs.append(str(self.low))
        cargs.append(str(self.high))
        return cargs


class MetricExtremaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `metric_extrema(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output extrema metric"""


def metric_extrema(
    surface: InputPathType,
    metric_in: InputPathType,
    distance: float,
    metric_out: str,
    presmooth: MetricExtremaPresmooth | None = None,
    opt_roi_roi_metric: InputPathType | None = None,
    threshold: MetricExtremaThreshold | None = None,
    opt_sum_columns: bool = False,
    opt_consolidate_mode: bool = False,
    opt_only_maxima: bool = False,
    opt_only_minima: bool = False,
    opt_column_column: str | None = None,
    runner: Runner | None = None,
) -> MetricExtremaOutputs:
    """
    Find extrema in a metric file.
    
    Finds extrema in a metric file, such that no two extrema of the same type
    are within <distance> of each other. The extrema are labeled as -1 for
    minima, 1 for maxima, 0 otherwise. If -only-maxima or -only-minima is
    specified, then it will ignore extrema not of the specified type. These
    options are mutually exclusive.
    
    If -roi is specified, not only is data outside the roi not used, but any
    vertex on the edge of the ROI will never be counted as an extrema, in case
    the ROI cuts across a gradient, which would otherwise generate extrema where
    there should be none.
    
    If -sum-columns is specified, these extrema columns are summed, and the
    output has a single column with this result.
    
    By default, a datapoint is an extrema only if it is more extreme than every
    other datapoint that is within <distance> from it. If -consolidate-mode is
    used, it instead starts by finding all datapoints that are more extreme than
    their immediate neighbors, then while there are any extrema within
    <distance> of each other, take the two extrema closest to each other and
    merge them into one by a weighted average based on how many original extrema
    have been merged into each.
    
    By default, all input columns are used with no smoothing, use -column to
    specify a single column to use, and -presmooth to smooth the input before
    finding the extrema.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface: the surface to use for distance information.
        metric_in: the metric to find the extrema of.
        distance: the minimum distance between identified extrema of the same\
            type.
        metric_out: the output extrema metric.
        presmooth: smooth the metric before finding extrema.
        opt_roi_roi_metric: ignore values outside the selected area: the area\
            to find extrema in, as a metric.
        threshold: ignore small extrema.
        opt_sum_columns: output the sum of the extrema columns instead of each\
            column separately.
        opt_consolidate_mode: use consolidation of local minima instead of a\
            large neighborhood.
        opt_only_maxima: only find the maxima.
        opt_only_minima: only find the minima.
        opt_column_column: select a single column to find extrema in: the\
            column number or name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricExtremaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_EXTREMA_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-extrema")
    cargs.append(execution.input_file(surface))
    cargs.append(execution.input_file(metric_in))
    cargs.append(str(distance))
    cargs.append(metric_out)
    if presmooth is not None:
        cargs.extend(presmooth.run(execution))
    if opt_roi_roi_metric is not None:
        cargs.extend([
            "-roi",
            execution.input_file(opt_roi_roi_metric)
        ])
    if threshold is not None:
        cargs.extend(threshold.run(execution))
    if opt_sum_columns:
        cargs.append("-sum-columns")
    if opt_consolidate_mode:
        cargs.append("-consolidate-mode")
    if opt_only_maxima:
        cargs.append("-only-maxima")
    if opt_only_minima:
        cargs.append("-only-minima")
    if opt_column_column is not None:
        cargs.extend([
            "-column",
            opt_column_column
        ])
    ret = MetricExtremaOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(metric_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "METRIC_EXTREMA_METADATA",
    "MetricExtremaOutputs",
    "MetricExtremaPresmooth",
    "MetricExtremaThreshold",
    "metric_extrema",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DEFACE_SUBJECT_METADATA = Metadata(
    id="274e5ad239a83bd50707ef1a9dcf8ce7c5e84775.boutiques",
    name="deface_subject",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class DefaceSubjectOutputs(typing.NamedTuple):
    """
    Output object returned when calling `deface_subject(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_volume: OutputPathType
    """Defaced output volume."""


def deface_subject(
    subjects_dir: str,
    subject_id: str,
    volume_input: InputPathType,
    volume_output: str,
    runner: Runner | None = None,
) -> DefaceSubjectOutputs:
    """
    Tool for defacing MRI images to anonymize patient data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subjects_dir: Directory containing FreeSurfer subject directories.
        subject_id: Subject ID that specifies the subject directory.
        volume_input: Input volume to be defaced.
        volume_output: Output volume after defacing.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DefaceSubjectOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DEFACE_SUBJECT_METADATA)
    cargs = []
    cargs.append("deface_subject")
    cargs.extend([
        "-sdir",
        subjects_dir
    ])
    cargs.extend([
        "-id",
        subject_id
    ])
    cargs.extend([
        "-i",
        execution.input_file(volume_input)
    ])
    cargs.extend([
        "-o",
        volume_output
    ])
    ret = DefaceSubjectOutputs(
        root=execution.output_file("."),
        output_volume=execution.output_file(volume_output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DEFACE_SUBJECT_METADATA",
    "DefaceSubjectOutputs",
    "deface_subject",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MIDTRANS_METADATA = Metadata(
    id="199624ee421c21ddcb5318e1c0213bf85f4d3c9a.boutiques",
    name="midtrans",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class MidtransOutputs(typing.NamedTuple):
    """
    Output object returned when calling `midtrans(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def midtrans(
    transforms: list[InputPathType],
    output_matrix: str | None = None,
    template_image: InputPathType | None = None,
    separate_basename: str | None = None,
    debug_flag: bool = False,
    verbose_flag: bool = False,
    runner: Runner | None = None,
) -> MidtransOutputs:
    """
    Calculate the midpoint transform from a series of input transforms.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        transforms: List of input transform files (e.g. transform1.mat\
            transform2.mat ... transformN.mat).
        output_matrix: Output filename for the resulting matrix.
        template_image: Input filename for template image (needed for fix\
            origin).
        separate_basename: Basename for the output of separate matrices (final\
            name includes a number; e.g. img2mid0001.mat).
        debug_flag: Switch on debugging output.
        verbose_flag: Switch on diagnostic messages.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MidtransOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MIDTRANS_METADATA)
    cargs = []
    cargs.append("midtrans")
    cargs.extend([execution.input_file(f) for f in transforms])
    if output_matrix is not None:
        cargs.extend([
            "-o",
            output_matrix
        ])
    if template_image is not None:
        cargs.extend([
            "--template",
            execution.input_file(template_image)
        ])
    if separate_basename is not None:
        cargs.extend([
            "--separate",
            separate_basename
        ])
    if debug_flag:
        cargs.append("--debug")
    if verbose_flag:
        cargs.append("-v, --verbose")
    ret = MidtransOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MIDTRANS_METADATA",
    "MidtransOutputs",
    "midtrans",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SEGMENT_HA_T1_SH_METADATA = Metadata(
    id="33c1985d7e603bd0c84961ad260a84289d2bd93f.boutiques",
    name="segmentHA_T1.sh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SegmentHaT1ShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `segment_ha_t1_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    hippocampus_aseg: OutputPathType
    """Segmented hippocampal subfields."""
    amygdala_aseg: OutputPathType
    """Segmented amygdalar subfields."""


def segment_ha_t1_sh(
    input_image: InputPathType,
    output_directory: str,
    brain_mask: InputPathType | None = None,
    verbose: bool = False,
    debug: bool = False,
    runner: Runner | None = None,
) -> SegmentHaT1ShOutputs:
    """
    Tool for hippocampal/amygdalar subfield segmentation.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_image: The input T1-weighted MRI image for hippocampal/amygdalar\
            segmentation.
        output_directory: The directory where the output will be saved.
        brain_mask: Use a specific brain mask for segmentation.
        verbose: Increase the verbosity of the output.
        debug: Enable debugging mode.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SegmentHaT1ShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SEGMENT_HA_T1_SH_METADATA)
    cargs = []
    cargs.append("segmentHA_T1.sh")
    cargs.append(execution.input_file(input_image))
    cargs.append(output_directory)
    if brain_mask is not None:
        cargs.extend([
            "--brainmask",
            execution.input_file(brain_mask)
        ])
    if verbose:
        cargs.append("--verbose")
    if debug:
        cargs.append("--debug")
    ret = SegmentHaT1ShOutputs(
        root=execution.output_file("."),
        hippocampus_aseg=execution.output_file(output_directory + "/hippocampus_aseg.mgz"),
        amygdala_aseg=execution.output_file(output_directory + "/amygdala_aseg.mgz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SEGMENT_HA_T1_SH_METADATA",
    "SegmentHaT1ShOutputs",
    "segment_ha_t1_sh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ISANALYZE_METADATA = Metadata(
    id="3d8f8ed4f2f6a0e189b0b47b6a3b1fc896553e24.boutiques",
    name="isanalyze",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class IsanalyzeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `isanalyze(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def isanalyze(
    input_file: InputPathType,
    runner: Runner | None = None,
) -> IsanalyzeOutputs:
    """
    A tool to analyze and process IS files.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input file for IS analysis.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `IsanalyzeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ISANALYZE_METADATA)
    cargs = []
    cargs.append("isanalyze")
    cargs.append(execution.input_file(input_file))
    ret = IsanalyzeOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ISANALYZE_METADATA",
    "IsanalyzeOutputs",
    "isanalyze",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_MULTI_THRESH_METADATA = Metadata(
    id="ac6c6a539a206612134e8a96c0fd7291780ddc36.boutiques",
    name="3dMultiThresh",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dMultiThreshOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_multi_thresh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType | None
    """Thresholded version of the input dataset."""
    mask_output: OutputPathType | None
    """0/1 mask dataset of voxels that survive the process."""
    all_mask_output: OutputPathType | None
    """Multi-volume dataset where each volume is the binary mask of voxels that
    pass ONE of the tests."""


def v_3d_multi_thresh(
    mthresh_file: InputPathType,
    input_file: InputPathType,
    index: float | None = None,
    signed_flag: str | None = None,
    positive_sign_flag: bool = False,
    negative_sign_flag: bool = False,
    prefix: str | None = None,
    mask_only_flag: bool = False,
    all_mask: str | None = None,
    no_zero_flag: bool = False,
    quiet_flag: bool = False,
    runner: Runner | None = None,
) -> V3dMultiThreshOutputs:
    """
    Program to apply a multi-threshold (mthresh) dataset to an input dataset.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        mthresh_file: Multi-threshold dataset from 3dXClustSim, usually via\
            running '3dttest++ -ETAC'.
        input_file: Dataset to threshold.
        index: Index (sub-brick) on which to threshold.
        signed_flag: Indicates if the .mthresh.nii file from 3dXClustSim was\
            created using 1-sided thresholding. Choose sign + or -.
        positive_sign_flag: Same as '-signed +'.
        negative_sign_flag: Same as '-signed -'.
        prefix: Prefix for output dataset. Can be 'NULL' to get no output\
            dataset.
        mask_only_flag: Instead of outputting a thresholded version of the\
            input dataset, just output a 0/1 mask dataset of voxels that survive\
            the process.
        all_mask: Write out a multi-volume dataset with prefix 'qqq' where each\
            volume is the binary mask of voxels that pass ONE of the tests.
        no_zero_flag: Prevents the output of a dataset if it would be all zero.
        quiet_flag: Turn off progress report messages.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dMultiThreshOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_MULTI_THRESH_METADATA)
    cargs = []
    cargs.append("3dMultiThresh")
    cargs.extend([
        "-mthresh",
        execution.input_file(mthresh_file)
    ])
    cargs.extend([
        "-input",
        execution.input_file(input_file)
    ])
    if index is not None:
        cargs.extend([
            "-1tindex",
            str(index)
        ])
    if signed_flag is not None:
        cargs.extend([
            "-signed",
            signed_flag
        ])
    if positive_sign_flag:
        cargs.append("-pos")
    if negative_sign_flag:
        cargs.append("-neg")
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if mask_only_flag:
        cargs.append("-maskonly")
    if all_mask is not None:
        cargs.extend([
            "-allmask",
            all_mask
        ])
    if no_zero_flag:
        cargs.append("-nozero")
    if quiet_flag:
        cargs.append("-quiet")
    ret = V3dMultiThreshOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(prefix + ".nii.gz") if (prefix is not None) else None,
        mask_output=execution.output_file(prefix + "_mask.nii.gz") if (prefix is not None) else None,
        all_mask_output=execution.output_file(all_mask + ".nii.gz") if (all_mask is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dMultiThreshOutputs",
    "V_3D_MULTI_THRESH_METADATA",
    "v_3d_multi_thresh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_ANOVA_METADATA = Metadata(
    id="a6b18c124721654a7ec2ffc70584424d3b14a440.boutiques",
    name="3dANOVA",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dAnovaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_anova(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    ftr_output: OutputPathType | None
    """Output F-statistic dataset file"""
    ftr_brick_output: OutputPathType | None
    """Output F-statistic BRIK file"""
    mean_output: OutputPathType | None
    """Output mean dataset file"""
    mean_brick_output: OutputPathType | None
    """Output mean BRIK file"""
    diff_output: OutputPathType | None
    """Output difference dataset file"""
    diff_brick_output: OutputPathType | None
    """Output difference BRIK file"""
    contr_output: OutputPathType | None
    """Output contrast dataset file"""
    contr_brick_output: OutputPathType | None
    """Output contrast BRIK file"""
    bucket_output: OutputPathType | None
    """Output bucket dataset file"""
    bucket_brick_output: OutputPathType | None
    """Output bucket BRIK file"""


def v_3d_anova(
    levels: int,
    datasets: list[str],
    voxel: int | None = None,
    diskspace: bool = False,
    mask: InputPathType | None = None,
    debug: int | None = None,
    ftr: str | None = None,
    mean: str | None = None,
    diff: str | None = None,
    contr: str | None = None,
    old_method: bool = False,
    ok: bool = False,
    assume_sph: bool = False,
    bucket: str | None = None,
    runner: Runner | None = None,
) -> V3dAnovaOutputs:
    """
    Performs single-factor Analysis of Variance (ANOVA) on 3D datasets.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        levels: Number of factor levels.
        datasets: Datasets for each factor level.
        voxel: Screen output for the specified voxel number.
        diskspace: Print out the required disk space for program execution.
        mask: Use sub-brick #0 of dataset to define which voxels to process.
        debug: Request extra output verbosity.
        ftr: F-statistic for treatment effect.
        mean: Estimate of factor level mean.
        diff: Difference between factor levels.
        contr: Contrast in factor levels.
        old_method: Perform ANOVA using the previous functionality.
        ok: Confirm understanding of t-stats and sphericity assumptions with\
            old method.
        assume_sph: Assume sphericity (zero-sum contrasts only).
        bucket: Create one AFNI 'bucket' dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dAnovaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_ANOVA_METADATA)
    cargs = []
    cargs.append("3dANOVA")
    cargs.extend([
        "-levels",
        str(levels)
    ])
    cargs.extend([
        "-dset",
        *datasets
    ])
    if voxel is not None:
        cargs.extend([
            "-voxel",
            str(voxel)
        ])
    if diskspace:
        cargs.append("-diskspace")
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if debug is not None:
        cargs.extend([
            "-debug",
            str(debug)
        ])
    if ftr is not None:
        cargs.extend([
            "-ftr",
            ftr
        ])
    if mean is not None:
        cargs.extend([
            "-mean",
            mean
        ])
    if diff is not None:
        cargs.extend([
            "-diff",
            diff
        ])
    if contr is not None:
        cargs.extend([
            "-contr",
            contr
        ])
    if old_method:
        cargs.append("-old_method")
    if ok:
        cargs.append("-OK")
    if assume_sph:
        cargs.append("-assume_sph")
    if bucket is not None:
        cargs.extend([
            "-bucket",
            bucket
        ])
    ret = V3dAnovaOutputs(
        root=execution.output_file("."),
        ftr_output=execution.output_file(ftr + ".HEAD") if (ftr is not None) else None,
        ftr_brick_output=execution.output_file(ftr + ".BRIK") if (ftr is not None) else None,
        mean_output=execution.output_file(mean + "_mean.HEAD") if (mean is not None) else None,
        mean_brick_output=execution.output_file(mean + "_mean.BRIK") if (mean is not None) else None,
        diff_output=execution.output_file(diff + "_diff.HEAD") if (diff is not None) else None,
        diff_brick_output=execution.output_file(diff + "_diff.BRIK") if (diff is not None) else None,
        contr_output=execution.output_file(contr + "_contr.HEAD") if (contr is not None) else None,
        contr_brick_output=execution.output_file(contr + "_contr.BRIK") if (contr is not None) else None,
        bucket_output=execution.output_file(bucket + ".HEAD") if (bucket is not None) else None,
        bucket_brick_output=execution.output_file(bucket + ".BRIK") if (bucket is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dAnovaOutputs",
    "V_3D_ANOVA_METADATA",
    "v_3d_anova",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FS_UPDATE_METADATA = Metadata(
    id="4603b7fb31c1aa61646a36fb25725ca6a61d057f.boutiques",
    name="fs_update",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FsUpdateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fs_update(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fs_update(
    update_path: str | None = None,
    help_long: bool = False,
    runner: Runner | None = None,
) -> FsUpdateOutputs:
    """
    Utility to update the FreeSurfer installation.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        update_path: Path to specific files or directories to update, copied\
            recursively.
        help_long:.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FsUpdateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FS_UPDATE_METADATA)
    cargs = []
    cargs.append("fs_update")
    if update_path is not None:
        cargs.append(update_path)
    if help_long:
        cargs.append("--help")
    ret = FsUpdateOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FS_UPDATE_METADATA",
    "FsUpdateOutputs",
    "fs_update",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FIXELCONVERT_METADATA = Metadata(
    id="61e22f7f494e1cc9061508aaffc5a41839e5a5fa.boutiques",
    name="fixelconvert",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class FixelconvertConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


@dataclasses.dataclass
class FixelconvertVariousString:
    obj: str
    """String object."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append(self.obj)
        return cargs


@dataclasses.dataclass
class FixelconvertVariousFile:
    obj: InputPathType
    """File object."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append(execution.input_file(self.obj))
        return cargs


@dataclasses.dataclass
class FixelconvertVariousString_:
    obj: str
    """String object."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append(self.obj)
        return cargs


@dataclasses.dataclass
class FixelconvertVariousFile_:
    obj: InputPathType
    """File object."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append(execution.input_file(self.obj))
        return cargs


class FixelconvertOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fixelconvert(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fixelconvert(
    fixel_in: typing.Union[FixelconvertVariousString, FixelconvertVariousFile],
    fixel_out: typing.Union[FixelconvertVariousString_, FixelconvertVariousFile_],
    name: str | None = None,
    nii: bool = False,
    out_size: bool = False,
    template: InputPathType | None = None,
    value: InputPathType | None = None,
    in_size: InputPathType | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[FixelconvertConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> FixelconvertOutputs:
    """
    Convert between the old format fixel image (.msf / .msh) and the new fixel
    directory format.
    
    
    
    References:
    
    .
    
    Author: MRTrix3 Developers
    
    URL: https://www.mrtrix.org/
    
    Args:
        fixel_in: the input fixel file / directory.
        fixel_out: the output fixel file / directory.
        name: assign a different name to the value field output (Default:\
            value). Do not include the file extension.
        nii: output the index, directions and data file in NIfTI format instead\
            of .mif.
        out_size: also output the 'size' field from the old format.
        template: specify an existing fixel directory (in the new format) to\
            which the new output should conform.
        value: nominate the data file to import to the 'value' field in the old\
            format.
        in_size: import data for the 'size' field in the old format.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FixelconvertOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FIXELCONVERT_METADATA)
    cargs = []
    cargs.append("fixelconvert")
    if name is not None:
        cargs.extend([
            "-name",
            name
        ])
    if nii:
        cargs.append("-nii")
    if out_size:
        cargs.append("-out_size")
    if template is not None:
        cargs.extend([
            "-template",
            execution.input_file(template)
        ])
    if value is not None:
        cargs.extend([
            "-value",
            execution.input_file(value)
        ])
    if in_size is not None:
        cargs.extend([
            "-in_size",
            execution.input_file(in_size)
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.extend(fixel_in.run(execution))
    cargs.extend(fixel_out.run(execution))
    ret = FixelconvertOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FIXELCONVERT_METADATA",
    "FixelconvertConfig",
    "FixelconvertOutputs",
    "FixelconvertVariousFile",
    "FixelconvertVariousFile_",
    "FixelconvertVariousString",
    "FixelconvertVariousString_",
    "fixelconvert",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FILMBABESCRIPT_METADATA = Metadata(
    id="c482f1ace2d9ca2fee7c3ed712be29e7f1ae595a.boutiques",
    name="filmbabescript",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FilmbabescriptOutputs(typing.NamedTuple):
    """
    Output object returned when calling `filmbabescript(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def filmbabescript(
    feat_dir: str,
    flobs_dir: str,
    runner: Runner | None = None,
) -> FilmbabescriptOutputs:
    """
    A tool/script for processing FEAT directories and FLOBs directories.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        feat_dir: Input FEAT directory.
        flobs_dir: Input FLOBs directory.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FilmbabescriptOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FILMBABESCRIPT_METADATA)
    cargs = []
    cargs.append("filmbabescript")
    cargs.append(feat_dir)
    cargs.append(flobs_dir)
    ret = FilmbabescriptOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FILMBABESCRIPT_METADATA",
    "FilmbabescriptOutputs",
    "filmbabescript",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GETFULLPATH_METADATA = Metadata(
    id="35adb422237513a6ef638025617ac7d09458620d.boutiques",
    name="getfullpath",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class GetfullpathOutputs(typing.NamedTuple):
    """
    Output object returned when calling `getfullpath(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def getfullpath(
    filename: str,
    runner: Runner | None = None,
) -> GetfullpathOutputs:
    """
    A utility to retrieve the full path of a specified file or directory.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        filename: Filename for which to get the full path.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GetfullpathOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GETFULLPATH_METADATA)
    cargs = []
    cargs.append("getfullpath")
    cargs.append(filename)
    ret = GetfullpathOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GETFULLPATH_METADATA",
    "GetfullpathOutputs",
    "getfullpath",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_TRANSFORM_METADATA = Metadata(
    id="bc7a45fd27e432a438c7967d047a12047b926e4c.boutiques",
    name="mri_transform",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriTransformOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_transform(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    transformed_output: OutputPathType
    """Transformed output volume"""


def mri_transform(
    input_volume: InputPathType,
    lta_file: InputPathType,
    output_file: str,
    out_like: InputPathType | None = None,
    invert: bool = False,
    runner: Runner | None = None,
) -> MriTransformOutputs:
    """
    Applies a linear transform to an MRI volume and writes out the result.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input MRI volume.
        lta_file: Linear Transform Array (LTA) file.
        output_file: Output file for the transformed MRI volume.
        out_like: Set output volume parameters like the reference volume.
        invert: Invert transform coordinates.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriTransformOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_TRANSFORM_METADATA)
    cargs = []
    cargs.append("mri_transform")
    cargs.append(execution.input_file(input_volume))
    cargs.append(execution.input_file(lta_file))
    cargs.append(output_file)
    if out_like is not None:
        cargs.extend([
            "-out_like",
            execution.input_file(out_like)
        ])
    if invert:
        cargs.append("-I")
    ret = MriTransformOutputs(
        root=execution.output_file("."),
        transformed_output=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_TRANSFORM_METADATA",
    "MriTransformOutputs",
    "mri_transform",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_HISTOGRAM_METADATA = Metadata(
    id="29a34e1d8dffc172e2f3223aff804ebe9bea2f93.boutiques",
    name="fsl_histogram",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FslHistogramOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_histogram(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    png_file: OutputPathType
    """Generated PNG file"""


def fsl_histogram(
    input_file_duplicate: InputPathType,
    output_file_duplicate: str,
    mask_file_duplicate: InputPathType | None = None,
    gmmfit_file_duplicate: InputPathType | None = None,
    plot_title_duplicate: str | None = None,
    legend_file_duplicate: InputPathType | None = None,
    xlabel_duplicate: str | None = None,
    ylabel_duplicate: str | None = None,
    plot_height_duplicate: float | None = None,
    plot_width_duplicate: float | None = None,
    num_bins_duplicate: float | None = None,
    zoom_factor_duplicate: float | None = None,
    use_gmm_flag: bool = False,
    runner: Runner | None = None,
) -> FslHistogramOutputs:
    """
    Histogram plotting tool for FSL.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_file_duplicate: Input file name.
        output_file_duplicate: Output filename for the PNG file.
        mask_file_duplicate: Mask file name.
        gmmfit_file_duplicate: File name of matrix with parameter estimates of\
            Gaussian/Gamma mixture model (means, variances and proportions per row).
        plot_title_duplicate: Plot title.
        legend_file_duplicate: File name of ASCII text file, one row per legend\
            entry.
        xlabel_duplicate: X-axis label.
        ylabel_duplicate: Y-axis label.
        plot_height_duplicate: Plot height in pixels (default 400).
        plot_width_duplicate: Plot width in pixels (default 600).
        num_bins_duplicate: Number of histogram bins.
        zoom_factor_duplicate: Zoom factor for y-range (e.g. 2.0).
        use_gmm_flag: Use Gaussian mixture model instead of Gaussian/Gamma\
            mixture model.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslHistogramOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_HISTOGRAM_METADATA)
    cargs = []
    cargs.append("fsl_histogram")
    cargs.extend([
        "--in",
        execution.input_file(input_file_duplicate)
    ])
    cargs.extend([
        "--out",
        output_file_duplicate
    ])
    if mask_file_duplicate is not None:
        cargs.extend([
            "--mask",
            execution.input_file(mask_file_duplicate)
        ])
    if gmmfit_file_duplicate is not None:
        cargs.extend([
            "--gmmfit",
            execution.input_file(gmmfit_file_duplicate)
        ])
    if plot_title_duplicate is not None:
        cargs.extend([
            "--title",
            plot_title_duplicate
        ])
    if legend_file_duplicate is not None:
        cargs.extend([
            "--legend",
            execution.input_file(legend_file_duplicate)
        ])
    if xlabel_duplicate is not None:
        cargs.extend([
            "--xlabel",
            xlabel_duplicate
        ])
    if ylabel_duplicate is not None:
        cargs.extend([
            "--ylabel",
            ylabel_duplicate
        ])
    if plot_height_duplicate is not None:
        cargs.extend([
            "--height",
            str(plot_height_duplicate)
        ])
    if plot_width_duplicate is not None:
        cargs.extend([
            "--width",
            str(plot_width_duplicate)
        ])
    if num_bins_duplicate is not None:
        cargs.extend([
            "--bins",
            str(num_bins_duplicate)
        ])
    if zoom_factor_duplicate is not None:
        cargs.extend([
            "--detail",
            str(zoom_factor_duplicate)
        ])
    if use_gmm_flag:
        cargs.append("--gmm")
    ret = FslHistogramOutputs(
        root=execution.output_file("."),
        png_file=execution.output_file(output_file_duplicate),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_HISTOGRAM_METADATA",
    "FslHistogramOutputs",
    "fsl_histogram",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_SURF2VTK_METADATA = Metadata(
    id="bfca7ed52c97191303bf209f7690859dfe93b483.boutiques",
    name="mris_surf2vtk",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisSurf2vtkOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_surf2vtk(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    vtk_surface: OutputPathType
    """Output surface file converted to VTK format"""


def mris_surf2vtk(
    input_surface: InputPathType,
    output_surface: str,
    runner: Runner | None = None,
) -> MrisSurf2vtkOutputs:
    """
    Conversion tool to convert surface files to VTK format.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_surface: Input surface file.
        output_surface: Output surface file in VTK format.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisSurf2vtkOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_SURF2VTK_METADATA)
    cargs = []
    cargs.append("mris_surf2vtk")
    cargs.extend([
        "-i",
        execution.input_file(input_surface)
    ])
    cargs.extend([
        "-o",
        output_surface
    ])
    ret = MrisSurf2vtkOutputs(
        root=execution.output_file("."),
        vtk_surface=execution.output_file(output_surface),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_SURF2VTK_METADATA",
    "MrisSurf2vtkOutputs",
    "mris_surf2vtk",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_MULTIMODAL_METADATA = Metadata(
    id="2538165a13ddb942b3f140f14c2c3852f648e85c.boutiques",
    name="mris_multimodal",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisMultimodalOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_multimodal(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    processed_output_surface: OutputPathType
    """Processed output surface file."""
    annotation_output_file: OutputPathType
    """Output file containing annotation data."""
    overlay_output_file: OutputPathType
    """Output file containing overlay data."""
    csv_output_file: OutputPathType
    """Output CSV file."""


def mris_multimodal(
    input_surface: InputPathType,
    target_surface: InputPathType,
    output_surface: InputPathType,
    annotation_output: InputPathType,
    overlay_output: InputPathType,
    csv_output: InputPathType,
    fill_holes: bool = False,
    curvature: bool = False,
    thickness: bool = False,
    vtk_output: bool = False,
    runner: Runner | None = None,
) -> MrisMultimodalOutputs:
    """
    A FreeSurfer tool for processing multimodal surface data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_surface: Input surface file.
        target_surface: Target surface file.
        output_surface: Output surface file.
        annotation_output: Output file for annotation data.
        overlay_output: Output file for overlay data.
        csv_output: Output CSV file.
        fill_holes: Flag to fill holes in the surface.
        curvature: Flag to process curvature data.
        thickness: Flag to process thickness data.
        vtk_output: Flag to output VTK file format.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisMultimodalOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_MULTIMODAL_METADATA)
    cargs = []
    cargs.append("mris_multimodal")
    cargs.extend([
        "-i",
        execution.input_file(input_surface)
    ])
    cargs.extend([
        "-t",
        execution.input_file(target_surface)
    ])
    cargs.extend([
        "-o",
        execution.input_file(output_surface)
    ])
    if fill_holes:
        cargs.append("-fillHoles")
    if curvature:
        cargs.append("--curvature")
    if thickness:
        cargs.append("--thickness")
    cargs.extend([
        "-a",
        execution.input_file(annotation_output)
    ])
    cargs.extend([
        "-v",
        execution.input_file(overlay_output)
    ])
    cargs.extend([
        "-c",
        execution.input_file(csv_output)
    ])
    if vtk_output:
        cargs.append("-vtk")
    ret = MrisMultimodalOutputs(
        root=execution.output_file("."),
        processed_output_surface=execution.output_file(pathlib.Path(output_surface).name),
        annotation_output_file=execution.output_file(pathlib.Path(annotation_output).name),
        overlay_output_file=execution.output_file(pathlib.Path(overlay_output).name),
        csv_output_file=execution.output_file(pathlib.Path(csv_output).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_MULTIMODAL_METADATA",
    "MrisMultimodalOutputs",
    "mris_multimodal",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_LINEAR_ALIGN_METADATA = Metadata(
    id="e21ce25c91e684ff7b180749c2270d4bd42ef69b.boutiques",
    name="mri_linear_align",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriLinearAlignOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_linear_align(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_linear_align(
    source: InputPathType,
    target: InputPathType,
    output_xform: str,
    runner: Runner | None = None,
) -> MriLinearAlignOutputs:
    """
    MRI Linear Alignment Tool for Freesurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        source: Source image file for alignment.
        target: Target image file for alignment.
        output_xform: Output transformation file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriLinearAlignOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_LINEAR_ALIGN_METADATA)
    cargs = []
    cargs.append("mri_linear_align")
    cargs.append(execution.input_file(source))
    cargs.append(execution.input_file(target))
    cargs.append(output_xform)
    ret = MriLinearAlignOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_LINEAR_ALIGN_METADATA",
    "MriLinearAlignOutputs",
    "mri_linear_align",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__BUILD_AFNI_XLIB_METADATA = Metadata(
    id="335ac2386eff0dba38cfaae81dacca730457f4a7.boutiques",
    name="@build_afni_Xlib",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VBuildAfniXlibOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__build_afni_xlib(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__build_afni_xlib(
    packages: list[str],
    localinstall: bool = False,
    debug_symbols: bool = False,
    lib64: bool = False,
    runner: Runner | None = None,
) -> VBuildAfniXlibOutputs:
    """
    Compile and install lesstif, openmotif, and/or libXt.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        packages: Packages to compile and install (e.g., lesstif, openmotif,\
            libXt).
        localinstall: Install under each package directory.
        debug_symbols: Compile with -g to add symbols.
        lib64: Install libs under lib64 (default is lib).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VBuildAfniXlibOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__BUILD_AFNI_XLIB_METADATA)
    cargs = []
    cargs.append("@build_afni_Xlib")
    if localinstall:
        cargs.append("-localinstall")
    if debug_symbols:
        cargs.append("-g")
    if lib64:
        cargs.append("-lib64")
    cargs.extend(packages)
    ret = VBuildAfniXlibOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VBuildAfniXlibOutputs",
    "V__BUILD_AFNI_XLIB_METADATA",
    "v__build_afni_xlib",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TILE_IMAGES_METADATA = Metadata(
    id="11f704401de392cf34f685f833e7073a2d69b714.boutiques",
    name="TileImages",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class TileImagesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tile_images(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    tiled_image: OutputPathType
    """The final tiled output image."""


def tile_images(
    image_dimension: int,
    output_image: InputPathType,
    layout: str,
    input_images: list[InputPathType],
    runner: Runner | None = None,
) -> TileImagesOutputs:
    """
    TileImages allows assembling images into a multi-dimensional array, producing a
    single output image. The input images must have a dimension less than or equal
    to the specified output image dimension.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: Dimensionality of the output image.
        output_image: The path for the output tiled image.
        layout: Defines the structure of the tiled output image. The layout\
            dictates the number and arrangement of input images in the output\
            image.
        input_images: Input images to be tiled into the output image. The\
            number of input images should match the layout specification.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TileImagesOutputs`).
    """
    if not (1 <= len(input_images)): 
        raise ValueError(f"Length of 'input_images' must be greater than 1 but was {len(input_images)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(TILE_IMAGES_METADATA)
    cargs = []
    cargs.append("TileImages")
    cargs.append(str(image_dimension))
    cargs.append(execution.input_file(output_image))
    cargs.append(layout)
    cargs.extend([execution.input_file(f) for f in input_images])
    ret = TileImagesOutputs(
        root=execution.output_file("."),
        tiled_image=execution.output_file(pathlib.Path(output_image).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TILE_IMAGES_METADATA",
    "TileImagesOutputs",
    "tile_images",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DMRI_MOTION_METADATA = Metadata(
    id="e4e3f3c86352739f602bc72ec495f7919e215248.boutiques",
    name="dmri_motion",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class DmriMotionOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dmri_motion(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    motion_measures_out: OutputPathType
    """Output file of motion measures"""
    frame_by_frame_out: OutputPathType | None
    """Output frame-by-frame motion measures file"""


def dmri_motion(
    outfile: InputPathType,
    outf: InputPathType | None = None,
    mat: InputPathType | None = None,
    dwi: list[InputPathType] | None = None,
    bval: list[InputPathType] | None = None,
    threshold: float | None = 100,
    diffusivity: float | None = 0.001,
    debug: bool = False,
    checkopts: bool = False,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> DmriMotionOutputs:
    """
    A tool for calculating motion measures from DWI scans.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        outfile: Output text file of motion measures.
        outf: Output text file of frame-by-frame motion measures.
        mat: Input text file of volume-to-baseline affine transformations.
        dwi: Input DWI scan(s), unprocessed.
        bval: Input b-value table(s), one per scan.
        threshold: Low-b image intensity threshold.
        diffusivity: Nominal diffusivity.
        debug: Turn on debugging.
        checkopts: Don't run anything, just check options and exit.
        help_: Print out information on how to use this program.
        version: Print out version and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DmriMotionOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DMRI_MOTION_METADATA)
    cargs = []
    cargs.append("dmri_motion")
    cargs.extend([
        "--out",
        execution.input_file(outfile)
    ])
    if outf is not None:
        cargs.extend([
            "--outf",
            execution.input_file(outf)
        ])
    if mat is not None:
        cargs.extend([
            "--mat",
            execution.input_file(mat)
        ])
    if dwi is not None:
        cargs.extend([
            "--dwi",
            *[execution.input_file(f) for f in dwi]
        ])
    if bval is not None:
        cargs.extend([
            "--bval",
            *[execution.input_file(f) for f in bval]
        ])
    if threshold is not None:
        cargs.extend([
            "--T",
            str(threshold)
        ])
    if diffusivity is not None:
        cargs.extend([
            "--D",
            str(diffusivity)
        ])
    if debug:
        cargs.append("--debug")
    if checkopts:
        cargs.append("--checkopts")
    if help_:
        cargs.append("--help")
    if version:
        cargs.append("--version")
    ret = DmriMotionOutputs(
        root=execution.output_file("."),
        motion_measures_out=execution.output_file(pathlib.Path(outfile).name),
        frame_by_frame_out=execution.output_file(pathlib.Path(outf).name) if (outf is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DMRI_MOTION_METADATA",
    "DmriMotionOutputs",
    "dmri_motion",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FAT_MAT_TABLEIZE_METADATA = Metadata(
    id="5ba44998c47e95e162b9d566a509d5fcbb197e51.boutiques",
    name="fat_mat_tableize",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class FatMatTableizeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fat_mat_tableize(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_table: OutputPathType
    """Table file usable in AFNI group analysis programs."""
    output_log: OutputPathType
    """Log file reporting inputs, matching, and aspects of creating the table
    file."""


def fat_mat_tableize(
    input_matrices: list[str],
    output_prefix: str,
    input_csv: InputPathType | None = None,
    input_list: InputPathType | None = None,
    parameters: list[str] | None = None,
    version: bool = False,
    date: bool = False,
    help_: bool = False,
    help_short: bool = False,
    help_view: bool = False,
    runner: Runner | None = None,
) -> FatMatTableizeOutputs:
    """
    Make tables for AFNI group analysis programs from 3dNetCorr (*.netcc) and
    3dTrackID (*.grid) outputs, with optional additional subject information from
    CSV files.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_matrices: Names of *.netcc or *.grid files with matrices to be\
            used to make table; can be provided using wildcard chars.
        output_prefix: Output basename for the table and log files. Suffix and\
            file extensions will be added for the outputs.
        input_csv: Name of a CSV file to include in the table. The first column\
            must have subject ID labels that match with the input matrix files.
        input_list: File containing paths to subject matrices and optionally\
            CSV IDs for matching.
        parameters: List of matrices to be included in the table, identified by\
            their parameter name.
        version: Display current version.
        date: Display release/editing date of current version.
        help_: Display help in terminal.
        help_short: Display help in terminal (short flag).
        help_view: Display help in a separate text editor.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FatMatTableizeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FAT_MAT_TABLEIZE_METADATA)
    cargs = []
    cargs.append("fat_mat_tableize.py")
    cargs.extend([
        "-in_mat",
        *input_matrices
    ])
    if input_csv is not None:
        cargs.extend([
            "-in_csv",
            execution.input_file(input_csv)
        ])
    if input_list is not None:
        cargs.extend([
            "-in_listfile",
            execution.input_file(input_list)
        ])
    cargs.extend([
        "-prefix",
        output_prefix
    ])
    if parameters is not None:
        cargs.extend([
            "-pars",
            *parameters
        ])
    if version:
        cargs.append("-ver")
    if date:
        cargs.append("-date")
    if help_:
        cargs.append("-help")
    if help_short:
        cargs.append("-h")
    if help_view:
        cargs.append("-hview")
    ret = FatMatTableizeOutputs(
        root=execution.output_file("."),
        output_table=execution.output_file(output_prefix + "_tbl.txt"),
        output_log=execution.output_file(output_prefix + "_prep.log"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FAT_MAT_TABLEIZE_METADATA",
    "FatMatTableizeOutputs",
    "fat_mat_tableize",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DMRI_TRK2TRK_METADATA = Metadata(
    id="7065b499ec2cb8133b9197d9f36d138deaee55a7.boutiques",
    name="dmri_trk2trk",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class DmriTrk2trkOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dmri_trk2trk(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_trk_file: OutputPathType | None
    """Transformed output .trk file"""
    out_asc_file: OutputPathType | None
    """Transformed output ASCII text file"""
    out_vol_file: OutputPathType | None
    """Transformed output volume"""


def dmri_trk2trk(
    in_trk: list[InputPathType],
    in_asc: list[InputPathType] | None = None,
    in_dir: str | None = None,
    out_trk: str | None = None,
    out_asc: str | None = None,
    out_vol: str | None = None,
    out_dir: str | None = None,
    in_ref: InputPathType | None = None,
    out_ref: InputPathType | None = None,
    reg_file: InputPathType | None = None,
    regnl_file: InputPathType | None = None,
    inv_flag: bool = False,
    fill_flag: bool = False,
    overlay: list[InputPathType] | None = None,
    inclusion_mask: list[InputPathType] | None = None,
    exclusion_mask: list[InputPathType] | None = None,
    terminal_inclusion_mask: list[InputPathType] | None = None,
    terminal_exclusion_mask: list[InputPathType] | None = None,
    length_min: float | None = None,
    length_max: float | None = None,
    mean_flag: bool = False,
    nearmean_flag: bool = False,
    nth_streamline: float | None = None,
    every_nth_streamline: float | None = None,
    smooth_flag: bool = False,
    debug_flag: bool = False,
    check_opts: bool = False,
    runner: Runner | None = None,
) -> DmriTrk2trkOutputs:
    """
    A tool for transforming and analyzing tractography data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        in_trk: Input .trk file(s).
        in_asc: Input ASCII plain text file(s), as an alternative to .trk.
        in_dir: Input directory (optional).
        out_trk: Output .trk file(s), as many as inputs (or 1 to merge inputs).
        out_asc: Output ASCII plain text file(s), as many as inputs (or 1 to\
            merge inputs).
        out_vol: Output volume(s), as many as inputs (or 1 to merge inputs).
        out_dir: Output directory (optional).
        in_ref: Input reference volume (needed for --reg/--regnl).
        out_ref: Output reference volume (needed for --reg/--regnl/--outvol).
        reg_file: Affine registration file (.lta or .mat), applied first.
        regnl_file: Nonlinear registration file (.m3z), applied second.
        inv_flag: Apply inverse of registration (default: no).
        fill_flag: Fill gaps b/w mapped points by linear interpolation.
        overlay: Scalar overlay 1D volume(s), applied to all input .trk files.
        inclusion_mask: Inclusion mask(s), applied to all input .trk files.
        exclusion_mask: Exclusion mask(s), applied to all input .trk files.
        terminal_inclusion_mask: Terminal inclusion mask(s), applied to all\
            input .trk files.
        terminal_exclusion_mask: Terminal exclusion mask(s), applied to all\
            input .trk files.
        length_min: Only save streamlines with length greater than this number.
        length_max: Only save streamlines with length smaller than this number.
        mean_flag: Only save the mean of the streamlines (Default: save all).
        nearmean_flag: Only save the streamline nearest to the mean (Default:\
            save all).
        nth_streamline: Only save the n-th (0-based) streamline (Default: save\
            all).
        every_nth_streamline: Only save every n-th streamline (Default: save\
            all).
        smooth_flag: Smooth streamlines (default: no).
        debug_flag: Turn on debugging.
        check_opts: Don't run anything, just check options and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DmriTrk2trkOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DMRI_TRK2TRK_METADATA)
    cargs = []
    cargs.append("dmri_trk2trk")
    cargs.extend([
        "--in",
        *[execution.input_file(f) for f in in_trk]
    ])
    if in_asc is not None:
        cargs.extend([
            "--inasc",
            *[execution.input_file(f) for f in in_asc]
        ])
    if in_dir is not None:
        cargs.extend([
            "--indir",
            in_dir
        ])
    if out_trk is not None:
        cargs.extend([
            "--out",
            out_trk
        ])
    if out_asc is not None:
        cargs.extend([
            "--outasc",
            out_asc
        ])
    if out_vol is not None:
        cargs.extend([
            "--outvol",
            out_vol
        ])
    if out_dir is not None:
        cargs.extend([
            "--outdir",
            out_dir
        ])
    if in_ref is not None:
        cargs.extend([
            "--inref",
            execution.input_file(in_ref)
        ])
    if out_ref is not None:
        cargs.extend([
            "--outref",
            execution.input_file(out_ref)
        ])
    if reg_file is not None:
        cargs.extend([
            "--reg",
            execution.input_file(reg_file)
        ])
    if regnl_file is not None:
        cargs.extend([
            "--regnl",
            execution.input_file(regnl_file)
        ])
    if inv_flag:
        cargs.append("--inv")
    if fill_flag:
        cargs.append("--fill")
    if overlay is not None:
        cargs.extend([
            "--over",
            *[execution.input_file(f) for f in overlay]
        ])
    if inclusion_mask is not None:
        cargs.extend([
            "--imask",
            *[execution.input_file(f) for f in inclusion_mask]
        ])
    if exclusion_mask is not None:
        cargs.extend([
            "--emask",
            *[execution.input_file(f) for f in exclusion_mask]
        ])
    if terminal_inclusion_mask is not None:
        cargs.extend([
            "--itmask",
            *[execution.input_file(f) for f in terminal_inclusion_mask]
        ])
    if terminal_exclusion_mask is not None:
        cargs.extend([
            "--etmask",
            *[execution.input_file(f) for f in terminal_exclusion_mask]
        ])
    if length_min is not None:
        cargs.extend([
            "--lmin",
            str(length_min)
        ])
    if length_max is not None:
        cargs.extend([
            "--lmax",
            str(length_max)
        ])
    if mean_flag:
        cargs.append("--mean")
    if nearmean_flag:
        cargs.append("--nearmean")
    if nth_streamline is not None:
        cargs.extend([
            "--nth",
            str(nth_streamline)
        ])
    if every_nth_streamline is not None:
        cargs.extend([
            "--every",
            str(every_nth_streamline)
        ])
    if smooth_flag:
        cargs.append("--smooth")
    if debug_flag:
        cargs.append("--debug")
    if check_opts:
        cargs.append("--checkopts")
    ret = DmriTrk2trkOutputs(
        root=execution.output_file("."),
        out_trk_file=execution.output_file(out_trk) if (out_trk is not None) else None,
        out_asc_file=execution.output_file(out_asc) if (out_asc is not None) else None,
        out_vol_file=execution.output_file(out_vol) if (out_vol is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DMRI_TRK2TRK_METADATA",
    "DmriTrk2trkOutputs",
    "dmri_trk2trk",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_MAKE_UCHAR_METADATA = Metadata(
    id="c299dc1179e4ab4f581f6357e1c8af3fbd1ff265.boutiques",
    name="mri_make_uchar",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriMakeUcharOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_make_uchar(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output volume from mri_make_uchar processing"""


def mri_make_uchar(
    input_volume: InputPathType,
    talairach_xform: InputPathType,
    output_volume: str,
    first_percentile: float | None = 0.01,
    wm_percentile: float | None = 0.9,
    max_radius: float | None = 50,
    cumulative_histo: str | None = None,
    vradvol: str | None = None,
    runner: Runner | None = None,
) -> MriMakeUcharOutputs:
    """
    Tool to adjust intensity of brain MRI images using a Talairach transformation.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input volume file.
        talairach_xform: Talairach transformation file.
        output_volume: Output volume file.
        first_percentile: First percentile for histogram calculation (default\
            0.01).
        wm_percentile: White matter percentile for histogram calculation\
            (default 0.9).
        max_radius: Maximum radius for voxel consideration (default 50).
        cumulative_histo: Cumulative histogram file.
        vradvol: Volume file where everything outside MAX_R is set to 0.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriMakeUcharOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_MAKE_UCHAR_METADATA)
    cargs = []
    cargs.append("mri_make_uchar")
    cargs.append(execution.input_file(input_volume))
    cargs.append(execution.input_file(talairach_xform))
    cargs.append(output_volume)
    if first_percentile is not None:
        cargs.extend([
            "-f",
            str(first_percentile)
        ])
    if wm_percentile is not None:
        cargs.extend([
            "-w",
            str(wm_percentile)
        ])
    if max_radius is not None:
        cargs.extend([
            "-r",
            str(max_radius)
        ])
    if cumulative_histo is not None:
        cargs.extend([
            "-h",
            cumulative_histo
        ])
    if vradvol is not None:
        cargs.extend([
            "-v",
            vradvol
        ])
    ret = MriMakeUcharOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_volume),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_MAKE_UCHAR_METADATA",
    "MriMakeUcharOutputs",
    "mri_make_uchar",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SLICER_METADATA = Metadata(
    id="7c28c8912deeb7ca0f43a49f175823fe5d4e25b2.boutiques",
    name="slicer",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class SlicerOutputs(typing.NamedTuple):
    """
    Output object returned when calling `slicer(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    sagittal_slice_outfile: OutputPathType | None
    """Output sagittal slice."""
    axial_slice_outfile: OutputPathType | None
    """Output axial slice."""
    coronal_slice_outfile: OutputPathType | None
    """Output coronal slice."""
    single_image_outfile: OutputPathType | None
    """Output mid-sagittal, -coronal, and -axial slices into one image."""
    all_axial_slices_outfile: OutputPathType | None
    """File name of every <sample'th> axial slice output image."""


def slicer(
    in_file: InputPathType,
    overlay_file: InputPathType | None = None,
    label_slices: bool = False,
    colour_map: InputPathType | None = None,
    scaling: float | None = None,
    intensity_range: list[float] | None = None,
    threshold_edges: float | None = None,
    dither_edges: bool = False,
    nearest_neighbour: bool = False,
    show_orientation: bool = False,
    red_dot_marker: bool = False,
    output_single_image: str | None = None,
    output_sagittal_slice: bool = False,
    output_sagittal_slice_fname: str | None = None,
    output_axial_slice: bool = False,
    output_axial_slice_fname: str | None = None,
    output_coronal_slice: bool = False,
    output_coronal_slice_fname: str | None = None,
    output_all_axial_slices: bool = False,
    output_all_axial_slices_fname: str | None = None,
    output_sample_axial_slices: bool = False,
    output_sample_axial_slices_width: str | None = None,
    output_sample_axial_slices_fname: str | None = None,
    runner: Runner | None = None,
) -> SlicerOutputs:
    """
    the main program which takes in one or two input images and produces as many
    separate output pictures of slices as are requested. The basic output options
    (-x, -y and -z) produce single slice pictures. The more advanced options (-a, -A
    and -S) produce montages of various slices. slicer outputs PPM format pictures.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        in_file: Input volume.
        overlay_file: Overlay volume.
        label_slices: Label slices with slice number.
        colour_map: Use different colour map from that specified in the header.
        scaling: Image scale.
        intensity_range: Specify intensity min and max for display range.
        threshold_edges: Use specified threshold for edges (if >0 use this\
            proportion of max-min, if <0, use the absolute value).
        dither_edges: Produce semi-transparent (dithered) edges.
        nearest_neighbour: Use nearest neighbor interpolation for output.
        show_orientation: Do not put left-right labels in output.
        red_dot_marker: Add a red dot marker to topright of image.
        output_single_image: Output mid-sagittal, -coronal, and -axial slices\
            into one image.
        output_sagittal_slice: Output sagittal slice (if slice >0, it is a\
            fraction of image dimension, if <0, it is absolute slice number).
        output_sagittal_slice_fname: Output file name sagittal slice.
        output_axial_slice: Output axial slice (if slice >0, it is a fraction\
            of image dimension, if <0, it is absolute slice number).
        output_axial_slice_fname: Output file name axial slice.
        output_coronal_slice: Output coronal slice (if slice >0, it is a\
            fraction of image dimension, if <0, it is absolute slice number).
        output_coronal_slice_fname: Output file name coronal slice.
        output_all_axial_slices: Maximum width of image of all axial slices.
        output_all_axial_slices_fname: File name of all axial slice output\
            image.
        output_sample_axial_slices: Ouput every <sample>'th axial slice.
        output_sample_axial_slices_width: Width of every <sample'th> axial\
            slice output image.
        output_sample_axial_slices_fname: File name of every <sample'th> axial\
            slice output image.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SlicerOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SLICER_METADATA)
    cargs = []
    cargs.append("slicer")
    cargs.append(execution.input_file(in_file))
    if overlay_file is not None:
        cargs.append(execution.input_file(overlay_file))
    if label_slices:
        cargs.append("-L")
    if colour_map is not None:
        cargs.extend([
            "-l",
            execution.input_file(colour_map)
        ])
    if scaling is not None:
        cargs.extend([
            "-s",
            str(scaling)
        ])
    if intensity_range is not None:
        cargs.extend([
            "-i",
            *map(str, intensity_range)
        ])
    if threshold_edges is not None:
        cargs.extend([
            "-e",
            str(threshold_edges)
        ])
    if dither_edges:
        cargs.append("-t")
    if nearest_neighbour:
        cargs.append("-n")
    if show_orientation:
        cargs.append("-u")
    if red_dot_marker:
        cargs.append("-c")
    cargs.append("...slices...")
    if output_single_image is not None:
        cargs.extend([
            "-a",
            output_single_image
        ])
    if output_sagittal_slice:
        cargs.append("-x")
    if output_sagittal_slice_fname is not None:
        cargs.append(output_sagittal_slice_fname)
    if output_axial_slice:
        cargs.append("-y")
    if output_axial_slice_fname is not None:
        cargs.append(output_axial_slice_fname)
    if output_coronal_slice:
        cargs.append("-z")
    if output_coronal_slice_fname is not None:
        cargs.append(output_coronal_slice_fname)
    if output_all_axial_slices:
        cargs.append("-A")
    if output_all_axial_slices_fname is not None:
        cargs.append(output_all_axial_slices_fname)
    if output_sample_axial_slices:
        cargs.append("-S")
    if output_sample_axial_slices_width is not None:
        cargs.append(output_sample_axial_slices_width)
    if output_sample_axial_slices_fname is not None:
        cargs.append(output_sample_axial_slices_fname)
    ret = SlicerOutputs(
        root=execution.output_file("."),
        sagittal_slice_outfile=execution.output_file(output_sagittal_slice_fname) if (output_sagittal_slice_fname is not None) else None,
        axial_slice_outfile=execution.output_file(output_axial_slice_fname) if (output_axial_slice_fname is not None) else None,
        coronal_slice_outfile=execution.output_file(output_coronal_slice_fname) if (output_coronal_slice_fname is not None) else None,
        single_image_outfile=execution.output_file(output_single_image) if (output_single_image is not None) else None,
        all_axial_slices_outfile=execution.output_file(output_sample_axial_slices_fname) if (output_sample_axial_slices_fname is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SLICER_METADATA",
    "SlicerOutputs",
    "slicer",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

XFMROT_METADATA = Metadata(
    id="e68f95765471172c3f4d5eecbc6fc6f118b60ba7.boutiques",
    name="xfmrot",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class XfmrotOutputs(typing.NamedTuple):
    """
    Output object returned when calling `xfmrot(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    transformed_vector: OutputPathType | None
    """The transformed output vector file with the same format as input."""


def xfmrot(
    transform_file: InputPathType,
    input_vector_file: InputPathType,
    output_vector_file: str | None = None,
    runner: Runner | None = None,
) -> XfmrotOutputs:
    """
    Tool to apply a transformation defined in a transform file to an input vector
    file.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        transform_file: Transform file, can be an eddy_correct/eddy log file or\
            a .mat file.
        input_vector_file: Input vector file which can be formatted in 3 rows\
            or 3 columns.
        output_vector_file: Output vector file will have the same format as\
            input.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `XfmrotOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(XFMROT_METADATA)
    cargs = []
    cargs.append("xfmrot")
    cargs.append(execution.input_file(transform_file))
    cargs.append(execution.input_file(input_vector_file))
    if output_vector_file is not None:
        cargs.append(output_vector_file)
    ret = XfmrotOutputs(
        root=execution.output_file("."),
        transformed_vector=execution.output_file(output_vector_file) if (output_vector_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "XFMROT_METADATA",
    "XfmrotOutputs",
    "xfmrot",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1D_TSORT_METADATA = Metadata(
    id="731309e5236007bd69df120b6a0494a5de798eeb.boutiques",
    name="1dTsort",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dTsortOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1d_tsort(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_1d_tsort(
    infile: InputPathType,
    dec_order: bool = False,
    transpose: bool = False,
    column: float | None = None,
    imode: bool = False,
    runner: Runner | None = None,
) -> V1dTsortOutputs:
    """
    Sorts each column of the input 1D file and writes result to stdout.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        infile: Input 1D file to be sorted.
        dec_order: Sort into decreasing order.
        transpose: Transpose the file before output.
        column: Sort only on column #j (counting starts at 0), and carry the\
            rest of the columns with it.
        imode: Typecast all values to integers, return the mode in the input\
            then exit. No sorting results are returned.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dTsortOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1D_TSORT_METADATA)
    cargs = []
    cargs.append("1dTsort")
    if dec_order:
        cargs.append("-dec")
    if transpose:
        cargs.append("-flip")
    if column is not None:
        cargs.extend([
            "-col",
            str(column)
        ])
    if imode:
        cargs.append("-imode")
    cargs.append(execution.input_file(infile))
    ret = V1dTsortOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dTsortOutputs",
    "V_1D_TSORT_METADATA",
    "v_1d_tsort",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TALSEGPROB_METADATA = Metadata(
    id="ddb70e26f179b8729ed68da2fa771aa79e55b360.boutiques",
    name="talsegprob",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class TalsegprobOutputs(typing.NamedTuple):
    """
    Output object returned when calling `talsegprob(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    probability_output_file: OutputPathType | None
    """Probability output file."""
    vote_output_file: OutputPathType | None
    """Vote output file."""
    concat_output_file: OutputPathType | None
    """Concatenated output file."""


def talsegprob(
    subjects_list: list[str] | None = None,
    fsgd_file: InputPathType | None = None,
    segmentation_number: float | None = None,
    second_segmentation_number: float | None = None,
    hippo_flag: bool = False,
    left_hippo_flag: bool = False,
    right_hippo_flag: bool = False,
    segmentation_file: InputPathType | None = None,
    probability_output: str | None = None,
    vote_output: str | None = None,
    concat_output: str | None = None,
    xform_file: InputPathType | None = None,
    subjects_dir: str | None = None,
    tmpdir: str | None = None,
    nocleanup_flag: bool = False,
    version_flag: bool = False,
    echo_flag: bool = False,
    runner: Runner | None = None,
) -> TalsegprobOutputs:
    """
    Tool to create a binary probability volume from aseg.mgz based on segmentation
    numbers, resliced to talirach/MNI305/fsaverage space.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subjects_list: List of subjects to include in the analysis.
        fsgd_file: FSGD file to get subject list.
        segmentation_number: Segmentation number.
        second_segmentation_number: Second segmentation number.
        hippo_flag: Use segmentation numbers 17 and 53.
        left_hippo_flag: Use segmentation number 17.
        right_hippo_flag: Use segmentation number 53.
        segmentation_file: Use subject/mri/segfile.mgz instead of aseg.
        probability_output: Probability output file name.
        vote_output: Vote output file name.
        concat_output: Concatenated output file name.
        xform_file: Transformation file to use (default is talairach.xfm).
        subjects_dir: SUBJECTS_DIR to use instead of the one in the\
            environment.
        tmpdir: Temporary directory (implies --nocleanup).
        nocleanup_flag: Do not delete temporary directory.
        version_flag: Display script version information.
        echo_flag: Enable command echo, for debug.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TalsegprobOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TALSEGPROB_METADATA)
    cargs = []
    cargs.append("talsegprob")
    if subjects_list is not None:
        cargs.extend([
            "--subjects",
            *subjects_list
        ])
    if fsgd_file is not None:
        cargs.extend([
            "--fsgd",
            execution.input_file(fsgd_file)
        ])
    if segmentation_number is not None:
        cargs.extend([
            "--seg",
            str(segmentation_number)
        ])
    if second_segmentation_number is not None:
        cargs.extend([
            "<--seg",
            str(second_segmentation_number)
        ])
    if hippo_flag:
        cargs.append("--hippo")
    if left_hippo_flag:
        cargs.append("--left-hippo")
    if right_hippo_flag:
        cargs.append("--right-hippo")
    if segmentation_file is not None:
        cargs.extend([
            "--segmentation",
            execution.input_file(segmentation_file)
        ])
    if probability_output is not None:
        cargs.extend([
            "--p",
            probability_output
        ])
    if vote_output is not None:
        cargs.extend([
            "--vote",
            vote_output
        ])
    if concat_output is not None:
        cargs.extend([
            "--c",
            concat_output
        ])
    if xform_file is not None:
        cargs.extend([
            "--xform",
            execution.input_file(xform_file)
        ])
    if subjects_dir is not None:
        cargs.extend([
            "--sdir",
            subjects_dir
        ])
    if tmpdir is not None:
        cargs.extend([
            "--tmpdir",
            tmpdir
        ])
    if nocleanup_flag:
        cargs.append("--nocleanup")
    if version_flag:
        cargs.append("--version")
    if echo_flag:
        cargs.append("--echo")
    ret = TalsegprobOutputs(
        root=execution.output_file("."),
        probability_output_file=execution.output_file(probability_output) if (probability_output is not None) else None,
        vote_output_file=execution.output_file(vote_output) if (vote_output is not None) else None,
        concat_output_file=execution.output_file(concat_output) if (concat_output is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TALSEGPROB_METADATA",
    "TalsegprobOutputs",
    "talsegprob",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_COMPUTE_LGI_METADATA = Metadata(
    id="336847c2bd9448a616f5ba616c1806f2492345d6.boutiques",
    name="mris_compute_lgi",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisComputeLgiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_compute_lgi(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_surface_map: OutputPathType
    """Surface map file containing local gyrification measures"""


def mris_compute_lgi(
    input_surface: InputPathType,
    close_sphere_size: float | None = None,
    smooth_iters: float | None = None,
    step_size: float | None = None,
    echo: bool = False,
    dontrun: bool = False,
    runner: Runner | None = None,
) -> MrisComputeLgiOutputs:
    """
    Computes local measurements of gyrification at thousands of points over the
    entire cortical surface.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_surface: Input surface file, typically lh.pial or rh.pial.
        close_sphere_size: Use sphere of specified size in mm for morph closing\
            operation (default: 15mm).
        smooth_iters: Smooth outer-surface specified number of iterations\
            (default: 30).
        step_size: Skip every specified number of vertices when computing lGI\
            (default: 100).
        echo: Enable command echo, for debug.
        dontrun: Just show commands (don't run them).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisComputeLgiOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_COMPUTE_LGI_METADATA)
    cargs = []
    cargs.append("mris_compute_lgi")
    cargs.extend([
        "--i",
        execution.input_file(input_surface)
    ])
    if close_sphere_size is not None:
        cargs.extend([
            "--close_sphere_size",
            str(close_sphere_size)
        ])
    if smooth_iters is not None:
        cargs.extend([
            "--smooth_iters",
            str(smooth_iters)
        ])
    if step_size is not None:
        cargs.extend([
            "--step_size",
            str(step_size)
        ])
    if echo:
        cargs.append("--echo")
    if dontrun:
        cargs.append("--dontrun")
    ret = MrisComputeLgiOutputs(
        root=execution.output_file("."),
        output_surface_map=execution.output_file(pathlib.Path(input_surface).name + "_lgi"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_COMPUTE_LGI_METADATA",
    "MrisComputeLgiOutputs",
    "mris_compute_lgi",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

NMOVIE_QT_METADATA = Metadata(
    id="40a52c883b6ef1eabbaca98341ef5cfeff36ee79.boutiques",
    name="nmovie_qt",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class NmovieQtOutputs(typing.NamedTuple):
    """
    Output object returned when calling `nmovie_qt(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def nmovie_qt(
    images: list[InputPathType],
    runner: Runner | None = None,
) -> NmovieQtOutputs:
    """
    An image viewer using Qt for displaying images in sequence.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        images: Input image files to be displayed. Multiple files can be\
            provided.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `NmovieQtOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(NMOVIE_QT_METADATA)
    cargs = []
    cargs.append("nmovie_qt")
    cargs.extend([execution.input_file(f) for f in images])
    ret = NmovieQtOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "NMOVIE_QT_METADATA",
    "NmovieQtOutputs",
    "nmovie_qt",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DMASKAVE_METADATA = Metadata(
    id="f43e3dde7ed7ffaf36c08fedc037f88f0b2a842f.boutiques",
    name="3dmaskave",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dmaskaveOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dmaskave(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file: OutputPathType
    """Output image file name."""
    out_file_: OutputPathType
    """Output file."""


def v_3dmaskave(
    in_file: InputPathType,
    mask: InputPathType | None = None,
    num_threads: int | None = None,
    outputtype: typing.Literal["NIFTI", "AFNI", "NIFTI_GZ"] | None = None,
    quiet: bool = False,
    runner: Runner | None = None,
) -> V3dmaskaveOutputs:
    """
    Computes average of all voxels in the input dataset which satisfy the criterion
    in the options list.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        in_file: Input file to 3dmaskave.
        mask: Matrix to align input file.
        num_threads: Set number of threads.
        outputtype: 'nifti' or 'afni' or 'nifti_gz'. Afni output filetype.
        quiet: Matrix to align input file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dmaskaveOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DMASKAVE_METADATA)
    cargs = []
    cargs.append("3dmaskave")
    cargs.append(execution.input_file(in_file))
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if num_threads is not None:
        cargs.append(str(num_threads))
    if outputtype is not None:
        cargs.append(outputtype)
    if quiet:
        cargs.append("-quiet")
    ret = V3dmaskaveOutputs(
        root=execution.output_file("."),
        out_file=execution.output_file(pathlib.Path(in_file).name + "_maskave.1D"),
        out_file_=execution.output_file("out_file"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dmaskaveOutputs",
    "V_3DMASKAVE_METADATA",
    "v_3dmaskave",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_SHARPEN_METADATA = Metadata(
    id="44eead3d035544b0d1ef18d1ea40f5df1b442bcb.boutiques",
    name="3dSharpen",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dSharpenOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_sharpen(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dataset: OutputPathType
    """Sharpened output dataset."""


def v_3d_sharpen(
    input_dataset: InputPathType,
    output_prefix: str,
    sharpening_factor: float | None = None,
    runner: Runner | None = None,
) -> V3dSharpenOutputs:
    """
    Applies a simple 3D sharpening filter to the positive values in the #0 volume of
    the input dataset, and writes out a new dataset.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_dataset: Input dataset (e.g., input.nii.gz).
        output_prefix: Name of the output dataset (e.g., output.nii.gz) which\
            will be in floating point format.
        sharpening_factor: Sharpening factor, between 0.1 and 0.9 (inclusive).\
            Larger values mean more sharpening.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dSharpenOutputs`).
    """
    if sharpening_factor is not None and not (0.1 <= sharpening_factor <= 0.9): 
        raise ValueError(f"'sharpening_factor' must be between 0.1 <= x <= 0.9 but was {sharpening_factor}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_SHARPEN_METADATA)
    cargs = []
    cargs.append("3dSharpen")
    if sharpening_factor is not None:
        cargs.extend([
            "-phi",
            str(sharpening_factor)
        ])
    cargs.append(execution.input_file(input_dataset))
    cargs.extend([
        "-prefix",
        output_prefix
    ])
    ret = V3dSharpenOutputs(
        root=execution.output_file("."),
        output_dataset=execution.output_file(output_prefix + ".nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dSharpenOutputs",
    "V_3D_SHARPEN_METADATA",
    "v_3d_sharpen",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MORPH_SUBJECT_METADATA = Metadata(
    id="685f97530d830d12a67cb8468c38864b69d1e65c.boutiques",
    name="morph_subject",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MorphSubjectOutputs(typing.NamedTuple):
    """
    Output object returned when calling `morph_subject(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def morph_subject(
    subjid: str,
    runner: Runner | None = None,
) -> MorphSubjectOutputs:
    """
    A morphological processing tool for Freesurfer subjects. The specific operations
    and options are not documented in the available help text.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subjid: Subject ID for processing.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MorphSubjectOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MORPH_SUBJECT_METADATA)
    cargs = []
    cargs.append("morph_subject")
    cargs.append(subjid)
    ret = MorphSubjectOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MORPH_SUBJECT_METADATA",
    "MorphSubjectOutputs",
    "morph_subject",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__2DWARPER_ALLIN_METADATA = Metadata(
    id="025f4fd73449077a7f27f71bce48a9a34a8bfe9d.boutiques",
    name="@2dwarper.Allin",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V2dwarperAllinOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__2dwarper_allin(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    reg_output: OutputPathType | None
    """Output registered dataset"""
    param_files: OutputPathType | None
    """Output registration parameter files"""


def v__2dwarper_allin(
    input_prefix: str,
    mask_prefix: str | None = None,
    output_prefix: str | None = None,
    runner: Runner | None = None,
) -> V2dwarperAllinOutputs:
    """
    Perform 2D registration on each slice of a 3D+time dataset, and combine the
    results.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_prefix: Prefix for the input 3D+time dataset.
        mask_prefix: Prefix of an existing mask dataset.
        output_prefix: Prefix for output datasets.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V2dwarperAllinOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__2DWARPER_ALLIN_METADATA)
    cargs = []
    cargs.append("@2dwarper.Allin")
    cargs.append(input_prefix)
    if mask_prefix is not None:
        cargs.extend([
            "-mask",
            mask_prefix
        ])
    if output_prefix is not None:
        cargs.extend([
            "-prefix",
            output_prefix
        ])
    ret = V2dwarperAllinOutputs(
        root=execution.output_file("."),
        reg_output=execution.output_file(output_prefix + "_reg+orig.HEAD") if (output_prefix is not None) else None,
        param_files=execution.output_file(output_prefix + "_param_*.1D") if (output_prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V2dwarperAllinOutputs",
    "V__2DWARPER_ALLIN_METADATA",
    "v__2dwarper_allin",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CONVERT_SCALAR_IMAGE_TO_RGB_METADATA = Metadata(
    id="bd90be2304f55e5624a9a746b1b00f9df35ab8d6.boutiques",
    name="ConvertScalarImageToRGB",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class ConvertScalarImageToRgbOutputs(typing.NamedTuple):
    """
    Output object returned when calling `convert_scalar_image_to_rgb(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_rgb_image: OutputPathType
    """The resulting RGB image after conversion."""


def convert_scalar_image_to_rgb(
    image_dimension: int,
    input_image: InputPathType,
    output_image: InputPathType,
    mask: InputPathType,
    colormap: typing.Literal["grey", "red", "green", "blue", "copper", "jet", "hsv", "spring", "summer", "autumn", "winter", "hot", "cool", "overunder", "custom"],
    custom_colormap_file: InputPathType | None = None,
    minimum_input: float | None = None,
    maximum_input: float | None = None,
    minimum_rgb_output: int | None = 0,
    maximum_rgb_output: int | None = 255,
    vtk_lookup_table: str | None = None,
    runner: Runner | None = None,
) -> ConvertScalarImageToRgbOutputs:
    """
    Converts a scalar image to an RGB image using specified parameters. Supports
    multiple colormap options and customization.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: The dimensionality of the image (e.g., 2D or 3D).
        input_image: The input scalar image to be converted to RGB.
        output_image: The output RGB image file.
        mask: The mask image to apply during conversion.
        colormap: The colormap to use for RGB conversion.
        custom_colormap_file: The file specifying the custom colormap (only\
            used if colormap is 'custom').
        minimum_input: The minimum input value for scaling.
        maximum_input: The maximum input value for scaling.
        minimum_rgb_output: The minimum output value for the RGB image.\
            Defaults to 0.
        maximum_rgb_output: The maximum output value for the RGB image.\
            Defaults to 255.
        vtk_lookup_table: The VTK lookup table to apply for additional\
            customization.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConvertScalarImageToRgbOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CONVERT_SCALAR_IMAGE_TO_RGB_METADATA)
    cargs = []
    cargs.append("ConvertScalarImageToRGB")
    cargs.append(str(image_dimension))
    cargs.append(execution.input_file(input_image))
    cargs.append(execution.input_file(output_image))
    cargs.append(execution.input_file(mask))
    cargs.append(colormap)
    if custom_colormap_file is not None:
        cargs.append(execution.input_file(custom_colormap_file))
    if minimum_input is not None:
        cargs.append(str(minimum_input))
    if maximum_input is not None:
        cargs.append(str(maximum_input))
    if minimum_rgb_output is not None:
        cargs.append(str(minimum_rgb_output))
    if maximum_rgb_output is not None:
        cargs.append(str(maximum_rgb_output))
    if vtk_lookup_table is not None:
        cargs.append(vtk_lookup_table)
    ret = ConvertScalarImageToRgbOutputs(
        root=execution.output_file("."),
        output_rgb_image=execution.output_file(pathlib.Path(output_image).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CONVERT_SCALAR_IMAGE_TO_RGB_METADATA",
    "ConvertScalarImageToRgbOutputs",
    "convert_scalar_image_to_rgb",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_RF_LONG_LABEL_METADATA = Metadata(
    id="06cc04cbd7f8fd46c1d7544632fa8c08486bcc37.boutiques",
    name="mri_rf_long_label",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriRfLongLabelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_rf_long_label(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_rf_long_label(
    help_flag: str | None = None,
    runner: Runner | None = None,
) -> MriRfLongLabelOutputs:
    """
    The mri_rf_long_label tool has been removed from this version of FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        help_flag: Displays a message that the tool has been removed.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriRfLongLabelOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_RF_LONG_LABEL_METADATA)
    cargs = []
    cargs.append("mri_rf_long_label")
    if help_flag is not None:
        cargs.append(help_flag)
    ret = MriRfLongLabelOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_RF_LONG_LABEL_METADATA",
    "MriRfLongLabelOutputs",
    "mri_rf_long_label",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MKMNC_INDEX_TCL_METADATA = Metadata(
    id="153ac6ba9dc33639bcc37f096fb83434f0b7cb92.boutiques",
    name="mkmnc_index.tcl",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MkmncIndexTclOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mkmnc_index_tcl(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    indexfile: OutputPathType
    """Generated index file"""


def mkmnc_index_tcl(
    infile: InputPathType,
    outfile: str,
    runner: Runner | None = None,
) -> MkmncIndexTclOutputs:
    """
    A tool for creating MINC indices.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        infile: Input MINC file.
        outfile: Output index file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MkmncIndexTclOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MKMNC_INDEX_TCL_METADATA)
    cargs = []
    cargs.append("mkmnc_index.tcl")
    cargs.append(execution.input_file(infile))
    cargs.append(outfile)
    ret = MkmncIndexTclOutputs(
        root=execution.output_file("."),
        indexfile=execution.output_file(outfile),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MKMNC_INDEX_TCL_METADATA",
    "MkmncIndexTclOutputs",
    "mkmnc_index_tcl",
]
